"""


Transform Operators
*******************

:func:`bbone_resize`

:func:`bend`

:func:`create_orientation`

:func:`delete_orientation`

:func:`edge_bevelweight`

:func:`edge_crease`

:func:`edge_slide`

:func:`from_gizmo`

:func:`mirror`

:func:`push_pull`

:func:`resize`

:func:`rotate`

:func:`rotate_normal`

:func:`select_orientation`

:func:`seq_slide`

:func:`shear`

:func:`shrink_fatten`

:func:`skin_resize`

:func:`tilt`

:func:`tosphere`

:func:`trackball`

:func:`transform`

:func:`translate`

:func:`vert_crease`

:func:`vert_slide`

:func:`vertex_random`

:func:`vertex_warp`

"""

import typing

import mathutils

def bbone_resize(value: mathutils.Vector = (1.0, 1.0, 1.0), orient_type: str = 'GLOBAL', orient_matrix: mathutils.Matrix = ((0.0, 0.0, 0.0), (0.0, 0.0, 0.0), (0.0, 0.0, 0.0)), orient_matrix_type: str = 'GLOBAL', constraint_axis: typing.Tuple[bool, bool, bool] = (False, False, False), mirror: bool = False, release_confirm: bool = False, use_accurate: bool = False) -> None:

  """

  Scale selected bendy bones display size

  """

  ...

def bend(value: typing.Tuple[float] = 0.0, mirror: bool = False, use_proportional_edit: bool = False, proportional_edit_falloff: str = 'SMOOTH', proportional_size: float = 1.0, use_proportional_connected: bool = False, use_proportional_projected: bool = False, snap: bool = False, gpencil_strokes: bool = False, center_override: mathutils.Vector = (0.0, 0.0, 0.0), release_confirm: bool = False, use_accurate: bool = False) -> None:

  """

  Bend selected items between the 3D cursor and the mouse

  """

  ...

def create_orientation(name: str = '', use_view: bool = False, use: bool = False, overwrite: bool = False) -> None:

  """

  Create transformation orientation from selection

  """

  ...

def delete_orientation() -> None:

  """

  Delete transformation orientation

  """

  ...

def edge_bevelweight(value: float = 0.0, snap: bool = False, release_confirm: bool = False, use_accurate: bool = False) -> None:

  """

  Change the bevel weight of edges

  """

  ...

def edge_crease(value: float = 0.0, snap: bool = False, release_confirm: bool = False, use_accurate: bool = False) -> None:

  """

  Change the crease of edges

  """

  ...

def edge_slide(value: float = 0.0, single_side: bool = False, use_even: bool = False, flipped: bool = False, use_clamp: bool = True, mirror: bool = False, snap: bool = False, snap_elements: typing.Set[str] = {'INCREMENT'}, use_snap_project: bool = False, snap_target: str = 'CLOSEST', use_snap_self: bool = True, use_snap_edit: bool = True, use_snap_nonedit: bool = True, use_snap_selectable: bool = False, snap_point: mathutils.Vector = (0.0, 0.0, 0.0), correct_uv: bool = True, release_confirm: bool = False, use_accurate: bool = False) -> None:

  """

  Slide an edge loop along a mesh

  """

  ...

def from_gizmo() -> None:

  """

  Transform selected items by mode type

  """

  ...

def mirror(orient_type: str = 'GLOBAL', orient_matrix: mathutils.Matrix = ((0.0, 0.0, 0.0), (0.0, 0.0, 0.0), (0.0, 0.0, 0.0)), orient_matrix_type: str = 'GLOBAL', constraint_axis: typing.Tuple[bool, bool, bool] = (False, False, False), gpencil_strokes: bool = False, center_override: mathutils.Vector = (0.0, 0.0, 0.0), release_confirm: bool = False, use_accurate: bool = False) -> None:

  """

  Mirror selected items around one or more axes

  """

  ...

def push_pull(value: float = 0.0, mirror: bool = False, use_proportional_edit: bool = False, proportional_edit_falloff: str = 'SMOOTH', proportional_size: float = 1.0, use_proportional_connected: bool = False, use_proportional_projected: bool = False, snap: bool = False, center_override: mathutils.Vector = (0.0, 0.0, 0.0), release_confirm: bool = False, use_accurate: bool = False) -> None:

  """

  Push/Pull selected items

  """

  ...

def resize(value: mathutils.Vector = (1.0, 1.0, 1.0), mouse_dir_constraint: mathutils.Vector = (0.0, 0.0, 0.0), orient_type: str = 'GLOBAL', orient_matrix: mathutils.Matrix = ((0.0, 0.0, 0.0), (0.0, 0.0, 0.0), (0.0, 0.0, 0.0)), orient_matrix_type: str = 'GLOBAL', constraint_axis: typing.Tuple[bool, bool, bool] = (False, False, False), mirror: bool = False, use_proportional_edit: bool = False, proportional_edit_falloff: str = 'SMOOTH', proportional_size: float = 1.0, use_proportional_connected: bool = False, use_proportional_projected: bool = False, snap: bool = False, snap_elements: typing.Set[str] = {'INCREMENT'}, use_snap_project: bool = False, snap_target: str = 'CLOSEST', use_snap_self: bool = True, use_snap_edit: bool = True, use_snap_nonedit: bool = True, use_snap_selectable: bool = False, snap_point: mathutils.Vector = (0.0, 0.0, 0.0), gpencil_strokes: bool = False, texture_space: bool = False, remove_on_cancel: bool = False, center_override: mathutils.Vector = (0.0, 0.0, 0.0), release_confirm: bool = False, use_accurate: bool = False) -> None:

  """

  Scale (resize) selected items

  """

  ...

def rotate(value: float = 0.0, orient_axis: str = 'Z', orient_type: str = 'GLOBAL', orient_matrix: mathutils.Matrix = ((0.0, 0.0, 0.0), (0.0, 0.0, 0.0), (0.0, 0.0, 0.0)), orient_matrix_type: str = 'GLOBAL', constraint_axis: typing.Tuple[bool, bool, bool] = (False, False, False), mirror: bool = False, use_proportional_edit: bool = False, proportional_edit_falloff: str = 'SMOOTH', proportional_size: float = 1.0, use_proportional_connected: bool = False, use_proportional_projected: bool = False, snap: bool = False, snap_elements: typing.Set[str] = {'INCREMENT'}, use_snap_project: bool = False, snap_target: str = 'CLOSEST', use_snap_self: bool = True, use_snap_edit: bool = True, use_snap_nonedit: bool = True, use_snap_selectable: bool = False, snap_point: mathutils.Vector = (0.0, 0.0, 0.0), gpencil_strokes: bool = False, center_override: mathutils.Vector = (0.0, 0.0, 0.0), release_confirm: bool = False, use_accurate: bool = False) -> None:

  """

  Rotate selected items

  """

  ...

def rotate_normal(value: float = 0.0, orient_axis: str = 'Z', orient_type: str = 'GLOBAL', orient_matrix: mathutils.Matrix = ((0.0, 0.0, 0.0), (0.0, 0.0, 0.0), (0.0, 0.0, 0.0)), orient_matrix_type: str = 'GLOBAL', constraint_axis: typing.Tuple[bool, bool, bool] = (False, False, False), mirror: bool = False, release_confirm: bool = False, use_accurate: bool = False) -> None:

  """

  Rotate split normal of selected items

  """

  ...

def select_orientation(orientation: str = 'GLOBAL') -> None:

  """

  Select transformation orientation

  """

  ...

def seq_slide(value: mathutils.Vector = (0.0, 0.0), snap: bool = False, view2d_edge_pan: bool = False, release_confirm: bool = False, use_accurate: bool = False) -> None:

  """

  Slide a sequence strip in time

  """

  ...

def shear(value: float = 0.0, orient_axis: str = 'Z', orient_axis_ortho: str = 'X', orient_type: str = 'GLOBAL', orient_matrix: mathutils.Matrix = ((0.0, 0.0, 0.0), (0.0, 0.0, 0.0), (0.0, 0.0, 0.0)), orient_matrix_type: str = 'GLOBAL', mirror: bool = False, use_proportional_edit: bool = False, proportional_edit_falloff: str = 'SMOOTH', proportional_size: float = 1.0, use_proportional_connected: bool = False, use_proportional_projected: bool = False, snap: bool = False, gpencil_strokes: bool = False, release_confirm: bool = False, use_accurate: bool = False) -> None:

  """

  Shear selected items along the horizontal screen axis

  """

  ...

def shrink_fatten(value: float = 0.0, use_even_offset: bool = False, mirror: bool = False, use_proportional_edit: bool = False, proportional_edit_falloff: str = 'SMOOTH', proportional_size: float = 1.0, use_proportional_connected: bool = False, use_proportional_projected: bool = False, snap: bool = False, release_confirm: bool = False, use_accurate: bool = False) -> None:

  """

  Shrink/fatten selected vertices along normals

  """

  ...

def skin_resize(value: mathutils.Vector = (1.0, 1.0, 1.0), orient_type: str = 'GLOBAL', orient_matrix: mathutils.Matrix = ((0.0, 0.0, 0.0), (0.0, 0.0, 0.0), (0.0, 0.0, 0.0)), orient_matrix_type: str = 'GLOBAL', constraint_axis: typing.Tuple[bool, bool, bool] = (False, False, False), mirror: bool = False, use_proportional_edit: bool = False, proportional_edit_falloff: str = 'SMOOTH', proportional_size: float = 1.0, use_proportional_connected: bool = False, use_proportional_projected: bool = False, snap: bool = False, snap_elements: typing.Set[str] = {'INCREMENT'}, use_snap_project: bool = False, snap_target: str = 'CLOSEST', use_snap_self: bool = True, use_snap_edit: bool = True, use_snap_nonedit: bool = True, use_snap_selectable: bool = False, snap_point: mathutils.Vector = (0.0, 0.0, 0.0), release_confirm: bool = False, use_accurate: bool = False) -> None:

  """

  Scale selected vertices' skin radii

  """

  ...

def tilt(value: float = 0.0, mirror: bool = False, use_proportional_edit: bool = False, proportional_edit_falloff: str = 'SMOOTH', proportional_size: float = 1.0, use_proportional_connected: bool = False, use_proportional_projected: bool = False, snap: bool = False, release_confirm: bool = False, use_accurate: bool = False) -> None:

  """

  Tilt selected control vertices of 3D curve

  """

  ...

def tosphere(value: float = 0.0, mirror: bool = False, use_proportional_edit: bool = False, proportional_edit_falloff: str = 'SMOOTH', proportional_size: float = 1.0, use_proportional_connected: bool = False, use_proportional_projected: bool = False, snap: bool = False, gpencil_strokes: bool = False, center_override: mathutils.Vector = (0.0, 0.0, 0.0), release_confirm: bool = False, use_accurate: bool = False) -> None:

  """

  Move selected items outward in a spherical shape around geometric center

  """

  ...

def trackball(value: typing.Tuple[float, float] = (0.0, 0.0), mirror: bool = False, use_proportional_edit: bool = False, proportional_edit_falloff: str = 'SMOOTH', proportional_size: float = 1.0, use_proportional_connected: bool = False, use_proportional_projected: bool = False, snap: bool = False, gpencil_strokes: bool = False, center_override: mathutils.Vector = (0.0, 0.0, 0.0), release_confirm: bool = False, use_accurate: bool = False) -> None:

  """

  Trackball style rotation of selected items

  """

  ...

def transform(mode: str = 'TRANSLATION', value: mathutils.Vector = (0.0, 0.0, 0.0, 0.0), orient_axis: str = 'Z', orient_type: str = 'GLOBAL', orient_matrix: mathutils.Matrix = ((0.0, 0.0, 0.0), (0.0, 0.0, 0.0), (0.0, 0.0, 0.0)), orient_matrix_type: str = 'GLOBAL', constraint_axis: typing.Tuple[bool, bool, bool] = (False, False, False), mirror: bool = False, use_proportional_edit: bool = False, proportional_edit_falloff: str = 'SMOOTH', proportional_size: float = 1.0, use_proportional_connected: bool = False, use_proportional_projected: bool = False, snap: bool = False, snap_elements: typing.Set[str] = {'INCREMENT'}, use_snap_project: bool = False, snap_target: str = 'CLOSEST', use_snap_self: bool = True, use_snap_edit: bool = True, use_snap_nonedit: bool = True, use_snap_selectable: bool = False, snap_point: mathutils.Vector = (0.0, 0.0, 0.0), snap_align: bool = False, snap_normal: mathutils.Vector = (0.0, 0.0, 0.0), gpencil_strokes: bool = False, center_override: mathutils.Vector = (0.0, 0.0, 0.0), release_confirm: bool = False, use_accurate: bool = False) -> None:

  """

  Transform selected items by mode type

  """

  ...

def translate(value: mathutils.Vector = (0.0, 0.0, 0.0), orient_type: str = 'GLOBAL', orient_matrix: mathutils.Matrix = ((0.0, 0.0, 0.0), (0.0, 0.0, 0.0), (0.0, 0.0, 0.0)), orient_matrix_type: str = 'GLOBAL', constraint_axis: typing.Tuple[bool, bool, bool] = (False, False, False), mirror: bool = False, use_proportional_edit: bool = False, proportional_edit_falloff: str = 'SMOOTH', proportional_size: float = 1.0, use_proportional_connected: bool = False, use_proportional_projected: bool = False, snap: bool = False, snap_elements: typing.Set[str] = {'INCREMENT'}, use_snap_project: bool = False, snap_target: str = 'CLOSEST', use_snap_self: bool = True, use_snap_edit: bool = True, use_snap_nonedit: bool = True, use_snap_selectable: bool = False, snap_point: mathutils.Vector = (0.0, 0.0, 0.0), snap_align: bool = False, snap_normal: mathutils.Vector = (0.0, 0.0, 0.0), gpencil_strokes: bool = False, cursor_transform: bool = False, texture_space: bool = False, remove_on_cancel: bool = False, view2d_edge_pan: bool = False, release_confirm: bool = False, use_accurate: bool = False, use_automerge_and_split: bool = False) -> None:

  """

  Move selected items

  """

  ...

def vert_crease(value: float = 0.0, snap: bool = False, release_confirm: bool = False, use_accurate: bool = False) -> None:

  """

  Change the crease of vertices

  """

  ...

def vert_slide(value: float = 0.0, use_even: bool = False, flipped: bool = False, use_clamp: bool = True, mirror: bool = False, snap: bool = False, snap_elements: typing.Set[str] = {'INCREMENT'}, use_snap_project: bool = False, snap_target: str = 'CLOSEST', use_snap_self: bool = True, use_snap_edit: bool = True, use_snap_nonedit: bool = True, use_snap_selectable: bool = False, snap_point: mathutils.Vector = (0.0, 0.0, 0.0), correct_uv: bool = True, release_confirm: bool = False, use_accurate: bool = False) -> None:

  """

  Slide a vertex along a mesh

  """

  ...

def vertex_random(offset: float = 0.0, uniform: float = 0.0, normal: float = 0.0, seed: int = 0, wait_for_input: bool = True) -> None:

  """

  Randomize vertices

  """

  ...

def vertex_warp(warp_angle: float = 6.28319, offset_angle: float = 0.0, min: float = -1.0, max: float = 1.0, viewmat: mathutils.Matrix = ((0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0), (0.0, 0.0, 0.0, 0.0)), center: mathutils.Vector = (0.0, 0.0, 0.0)) -> None:

  """

  Warp vertices around the cursor

  """

  ...



"""


Space Sequencer View Type Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:SEQUENCER:       
  Sequencer.

:PREVIEW:         
  Preview.

:SEQUENCER_PREVIEW:
  Sequencer & Preview.

.. _rna-enum-space-sequencer-view-type-items:

"""

import typing



"""


Image Operators
***************

:func:`add_render_slot`

:func:`change_frame`

:func:`clear_render_border`

:func:`clear_render_slot`

:func:`curves_point_set`

:func:`cycle_render_slot`

:func:`external_edit`

:func:`file_browse`

:func:`flip`

:func:`invert`

:func:`match_movie_length`

:func:`new`

:func:`open`

:func:`pack`

:func:`project_apply`

:func:`project_edit`

:func:`read_viewlayers`

:func:`reload`

:func:`remove_render_slot`

:func:`render_border`

:func:`replace`

:func:`resize`

:func:`sample`

:func:`sample_line`

:func:`save`

:func:`save_all_modified`

:func:`save_as`

:func:`save_sequence`

:func:`tile_add`

:func:`tile_fill`

:func:`tile_remove`

:func:`unpack`

:func:`view_all`

:func:`view_center_cursor`

:func:`view_cursor_center`

:func:`view_pan`

:func:`view_selected`

:func:`view_zoom`

:func:`view_zoom_border`

:func:`view_zoom_in`

:func:`view_zoom_out`

:func:`view_zoom_ratio`

"""

import typing

import mathutils

def add_render_slot() -> None:

  """

  Add a new render slot

  """

  ...

def change_frame(frame: int = 0) -> None:

  """

  Interactively change the current frame number

  """

  ...

def clear_render_border() -> None:

  """

  Clear the boundaries of the render region and disable render region

  """

  ...

def clear_render_slot() -> None:

  """

  Clear the currently selected render slot

  """

  ...

def curves_point_set(point: str = 'BLACK_POINT', size: int = 1) -> None:

  """

  Set black point or white point for curves

  """

  ...

def cycle_render_slot(reverse: bool = False) -> None:

  """

  Cycle through all non-void render slots

  """

  ...

def external_edit(filepath: str = '') -> None:

  """

  Edit image in an external application

  :file:`startup/bl_operators/image.py\:44 <https://projects.blender.org/blender/blender/src/branch/main/scripts/startup/bl_operators/image.py#L44>`_

  """

  ...

def file_browse(filepath: str = '', hide_props_region: bool = True, check_existing: bool = False, filter_blender: bool = False, filter_backup: bool = False, filter_image: bool = True, filter_movie: bool = True, filter_python: bool = False, filter_font: bool = False, filter_sound: bool = False, filter_text: bool = False, filter_archive: bool = False, filter_btx: bool = False, filter_collada: bool = False, filter_alembic: bool = False, filter_usd: bool = False, filter_obj: bool = False, filter_volume: bool = False, filter_folder: bool = True, filter_blenlib: bool = False, filemode: int = 9, relative_path: bool = True, show_multiview: bool = False, use_multiview: bool = False, display_type: str = 'DEFAULT', sort_method: str = '') -> None:

  """

  Open an image file browser, hold Shift to open the file, Alt to browse containing directory

  """

  ...

def flip(use_flip_x: bool = False, use_flip_y: bool = False) -> None:

  """

  Flip the image

  """

  ...

def invert(invert_r: bool = False, invert_g: bool = False, invert_b: bool = False, invert_a: bool = False) -> None:

  """

  Invert image's channels

  """

  ...

def match_movie_length() -> None:

  """

  Set image's user's length to the one of this video

  """

  ...

def new(name: str = 'Untitled', width: int = 1024, height: int = 1024, color: typing.Tuple[float, float, float, float] = (0.0, 0.0, 0.0, 1.0), alpha: bool = True, generated_type: str = 'BLANK', float: bool = False, use_stereo_3d: bool = False, tiled: bool = False) -> None:

  """

  Create a new image

  """

  ...

def open(allow_path_tokens: bool = True, filepath: str = '', directory: str = '', files: typing.Union[typing.Sequence[OperatorFileListElement], typing.Mapping[str, OperatorFileListElement], bpy.types.bpy_prop_collection] = None, hide_props_region: bool = True, check_existing: bool = False, filter_blender: bool = False, filter_backup: bool = False, filter_image: bool = True, filter_movie: bool = True, filter_python: bool = False, filter_font: bool = False, filter_sound: bool = False, filter_text: bool = False, filter_archive: bool = False, filter_btx: bool = False, filter_collada: bool = False, filter_alembic: bool = False, filter_usd: bool = False, filter_obj: bool = False, filter_volume: bool = False, filter_folder: bool = True, filter_blenlib: bool = False, filemode: int = 9, relative_path: bool = True, show_multiview: bool = False, use_multiview: bool = False, display_type: str = 'DEFAULT', sort_method: str = '', use_sequence_detection: bool = True, use_udim_detecting: bool = True) -> None:

  """

  Open image

  """

  ...

def pack() -> None:

  """

  Pack an image as embedded data into the .blend file

  """

  ...

def project_apply() -> None:

  """

  Project edited image back onto the object

  :file:`startup/bl_operators/image.py\:179 <https://projects.blender.org/blender/blender/src/branch/main/scripts/startup/bl_operators/image.py#L179>`_

  """

  ...

def project_edit() -> None:

  """

  Edit a snapshot of the 3D Viewport in an external image editor

  :file:`startup/bl_operators/image.py\:109 <https://projects.blender.org/blender/blender/src/branch/main/scripts/startup/bl_operators/image.py#L109>`_

  """

  ...

def read_viewlayers() -> None:

  """

  Read all the current scene's view layers from cache, as needed

  """

  ...

def reload() -> None:

  """

  Reload current image from disk

  """

  ...

def remove_render_slot() -> None:

  """

  Remove the current render slot

  """

  ...

def render_border(xmin: int = 0, xmax: int = 0, ymin: int = 0, ymax: int = 0, wait_for_input: bool = True) -> None:

  """

  Set the boundaries of the render region and enable render region

  """

  ...

def replace(filepath: str = '', hide_props_region: bool = True, check_existing: bool = False, filter_blender: bool = False, filter_backup: bool = False, filter_image: bool = True, filter_movie: bool = True, filter_python: bool = False, filter_font: bool = False, filter_sound: bool = False, filter_text: bool = False, filter_archive: bool = False, filter_btx: bool = False, filter_collada: bool = False, filter_alembic: bool = False, filter_usd: bool = False, filter_obj: bool = False, filter_volume: bool = False, filter_folder: bool = True, filter_blenlib: bool = False, filemode: int = 9, relative_path: bool = True, show_multiview: bool = False, use_multiview: bool = False, display_type: str = 'DEFAULT', sort_method: str = '') -> None:

  """

  Replace current image by another one from disk

  """

  ...

def resize(size: typing.Tuple[int, int] = (0, 0)) -> None:

  """

  Resize the image

  """

  ...

def sample(size: int = 1) -> None:

  """

  Use mouse to sample a color in current image

  """

  ...

def sample_line(xstart: int = 0, xend: int = 0, ystart: int = 0, yend: int = 0, flip: bool = False, cursor: int = 5) -> None:

  """

  Sample a line and show it in Scope panels

  """

  ...

def save() -> None:

  """

  Save the image with current name and settings

  """

  ...

def save_all_modified() -> None:

  """

  Save all modified images

  """

  ...

def save_as(save_as_render: bool = False, copy: bool = False, allow_path_tokens: bool = True, filepath: str = '', check_existing: bool = True, filter_blender: bool = False, filter_backup: bool = False, filter_image: bool = True, filter_movie: bool = True, filter_python: bool = False, filter_font: bool = False, filter_sound: bool = False, filter_text: bool = False, filter_archive: bool = False, filter_btx: bool = False, filter_collada: bool = False, filter_alembic: bool = False, filter_usd: bool = False, filter_obj: bool = False, filter_volume: bool = False, filter_folder: bool = True, filter_blenlib: bool = False, filemode: int = 9, relative_path: bool = True, show_multiview: bool = False, use_multiview: bool = False, display_type: str = 'DEFAULT', sort_method: str = '') -> None:

  """

  Save the image with another name and/or settings

  """

  ...

def save_sequence() -> None:

  """

  Save a sequence of images

  """

  ...

def tile_add(number: int = 1002, count: int = 1, label: str = '', fill: bool = True, color: typing.Tuple[float, float, float, float] = (0.0, 0.0, 0.0, 1.0), generated_type: str = 'BLANK', width: int = 1024, height: int = 1024, float: bool = False, alpha: bool = True) -> None:

  """

  Adds a tile to the image

  """

  ...

def tile_fill(color: typing.Tuple[float, float, float, float] = (0.0, 0.0, 0.0, 1.0), generated_type: str = 'BLANK', width: int = 1024, height: int = 1024, float: bool = False, alpha: bool = True) -> None:

  """

  Fill the current tile with a generated image

  """

  ...

def tile_remove() -> None:

  """

  Removes a tile from the image

  """

  ...

def unpack(method: str = 'USE_LOCAL', id: str = '') -> None:

  """

  Save an image packed in the .blend file to disk

  """

  ...

def view_all(fit_view: bool = False) -> None:

  """

  View the entire image

  """

  ...

def view_center_cursor() -> None:

  """

  Center the view so that the cursor is in the middle of the view

  """

  ...

def view_cursor_center(fit_view: bool = False) -> None:

  """

  Set 2D Cursor To Center View location

  """

  ...

def view_pan(offset: mathutils.Vector = (0.0, 0.0)) -> None:

  """

  Pan the view

  """

  ...

def view_selected() -> None:

  """

  View all selected UVs

  """

  ...

def view_zoom(factor: float = 0.0, use_cursor_init: bool = True) -> None:

  """

  Zoom in/out the image

  """

  ...

def view_zoom_border(xmin: int = 0, xmax: int = 0, ymin: int = 0, ymax: int = 0, wait_for_input: bool = True, zoom_out: bool = False) -> None:

  """

  Zoom in the view to the nearest item contained in the border

  """

  ...

def view_zoom_in(location: mathutils.Vector = (0.0, 0.0)) -> None:

  """

  Zoom in the image (centered around 2D cursor)

  """

  ...

def view_zoom_out(location: mathutils.Vector = (0.0, 0.0)) -> None:

  """

  Zoom out the image (centered around 2D cursor)

  """

  ...

def view_zoom_ratio(ratio: float = 0.0) -> None:

  """

  Set zoom ratio of the view

  """

  ...



"""


Motionpath Display Type Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:CURRENT_FRAME:   
  Around Frame.

  Display Paths of poses within a fixed number of frames around the current frame.

:RANGE:           
  In Range.

  Display Paths of poses within specified range.

.. _rna-enum-motionpath-display-type-items:

"""

import typing



"""


ID Property Access (idprop.types)
*********************************

:class:`IDPropertyArray`

:class:`IDPropertyGroup`

:class:`IDPropertyGroupIterItems`

:class:`IDPropertyGroupIterKeys`

:class:`IDPropertyGroupIterValues`

:class:`IDPropertyGroupViewItems`

:class:`IDPropertyGroupViewKeys`

:class:`IDPropertyGroupViewValues`

"""

import typing

class IDPropertyArray:

  def to_list(self) -> None:

    """

    Return the array as a list.

    """

    ...

  typecode: typing.Any = ...

  """

  The type of the data in the array {'f': float, 'd': double, 'i': int, 'b': bool}.

  """

class IDPropertyGroup:

  """"""

  def clear(self) -> None:

    """

    Clear all members from this group.

    """

    ...

  def get(self, key: typing.Any, default: typing.Any = None) -> None:

    """

    Return the value for key, if it exists, else default.

    """

    ...

  def items(self) -> None:

    """

    Iterate through the items in the dict; behaves like dictionary method items.

    """

    ...

  def keys(self) -> None:

    """

    Return the keys associated with this group as a list of strings.

    """

    ...

  def pop(self, key: str, default: typing.Any) -> None:

    """

    Remove an item from the group, returning a Python representation.

    """

    ...

  def to_dict(self) -> None:

    """

    Return a purely python version of the group.

    """

    ...

  def update(self, other: typing.Union[IDPropertyGroup, typing.Dict[str, typing.Any]]) -> None:

    """

    Update key, values.

    """

    ...

  def values(self) -> None:

    """

    Return the values associated with this group.

    """

    ...

  name: typing.Any = ...

  """

  The name of this Group.

  """

class IDPropertyGroupIterItems:

  ...

class IDPropertyGroupIterKeys:

  ...

class IDPropertyGroupIterValues:

  ...

class IDPropertyGroupViewItems:

  ...

class IDPropertyGroupViewKeys:

  ...

class IDPropertyGroupViewValues:

  ...



"""


Attribute Type Items
^^^^^^^^^^^^^^^^^^^^

:FLOAT:           
  Float.

  Floating-point value.

:INT:             
  Integer.

  32-bit integer.

:FLOAT_VECTOR:    
  Vector.

  3D vector with floating-point values.

:FLOAT_COLOR:     
  Color.

  RGBA color with 32-bit floating-point values.

:BYTE_COLOR:      
  Byte Color.

  RGBA color with 8-bit positive integer values.

:STRING:          
  String.

  Text string.

:BOOLEAN:         
  Boolean.

  True or false.

:FLOAT2:          
  2D Vector.

  2D vector with floating-point values.

:INT8:            
  8-Bit Integer.

  Smaller integer with a range from -128 to 127.

.. _rna-enum-attribute-type-items:

"""

import typing



"""


Fileselect Params Sort Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:FILE_SORT_ALPHA: 
  Name.

  Sort the file list alphabetically.

:FILE_SORT_EXTENSION:
  Extension.

  Sort the file list by extension/type.

:FILE_SORT_TIME:  
  Modified Date.

  Sort files by modification time.

:FILE_SORT_SIZE:  
  Size.

  Sort files by size.

.. _rna-enum-fileselect-params-sort-items:

"""

import typing



"""


bpy_extras submodule (bpy_extras.node_utils)
********************************************

:func:`find_node_input`

"""

import typing

def find_node_input(node: typing.Any, name: typing.Any) -> None:

  ...



"""


Paintcurve Operators
********************

:func:`add_point`

:func:`add_point_slide`

:func:`cursor`

:func:`delete_point`

:func:`draw`

:func:`new`

:func:`select`

:func:`slide`

"""

import typing

def add_point(location: typing.Tuple[int, int] = (0, 0)) -> None:

  """

  Add New Paint Curve Point

  """

  ...

def add_point_slide(PAINTCURVE_OT_add_point: PAINTCURVE_OT_add_point = None, PAINTCURVE_OT_slide: PAINTCURVE_OT_slide = None) -> None:

  """

  Add new curve point and slide it

  """

  ...

def cursor() -> None:

  """

  Place cursor

  """

  ...

def delete_point() -> None:

  """

  Remove Paint Curve Point

  """

  ...

def draw() -> None:

  """

  Draw curve

  """

  ...

def new() -> None:

  """

  Add new paint curve

  """

  ...

def select(location: typing.Tuple[int, int] = (0, 0), toggle: bool = False, extend: bool = False) -> None:

  """

  Select a paint curve point

  """

  ...

def slide(align: bool = False, select: bool = True) -> None:

  """

  Select and slide paint curve point

  """

  ...



"""


Snap Element Items
^^^^^^^^^^^^^^^^^^

:INCREMENT:       
  Increment.

  Snap to increments of grid.

:VERTEX:          
  Vertex.

  Snap to vertices.

:EDGE:            
  Edge.

  Snap to edges.

:FACE:            
  Face Project.

  Snap by projecting onto faces.

:FACE_NEAREST:    
  Face Nearest.

  Snap to nearest point on faces.

:VOLUME:          
  Volume.

  Snap to volume.

:EDGE_MIDPOINT:   
  Edge Center.

  Snap to the middle of edges.

:EDGE_PERPENDICULAR:
  Edge Perpendicular.

  Snap to the nearest point on an edge.

.. _rna-enum-snap-element-items:

"""

import typing



"""


Object Rotation Mode Items
^^^^^^^^^^^^^^^^^^^^^^^^^^

:QUATERNION:      
  Quaternion (WXYZ).

  No Gimbal Lock.

:XYZ:             
  XYZ Euler.

  XYZ Rotation Order - prone to Gimbal Lock (default).

:XZY:             
  XZY Euler.

  XZY Rotation Order - prone to Gimbal Lock.

:YXZ:             
  YXZ Euler.

  YXZ Rotation Order - prone to Gimbal Lock.

:YZX:             
  YZX Euler.

  YZX Rotation Order - prone to Gimbal Lock.

:ZXY:             
  ZXY Euler.

  ZXY Rotation Order - prone to Gimbal Lock.

:ZYX:             
  ZYX Euler.

  ZYX Rotation Order - prone to Gimbal Lock.

:AXIS_ANGLE:      
  Axis Angle.

  Axis Angle (W+XYZ), defines a rotation around some axis defined by 3D-Vector.

.. _rna-enum-object-rotation-mode-items:

"""

import typing



"""


Brush Gpencil Types Items
^^^^^^^^^^^^^^^^^^^^^^^^^

:DRAW:            
  Draw.

  The brush is of type used for drawing strokes.

:FILL:            
  Fill.

  The brush is of type used for filling areas.

:ERASE:           
  Erase.

  The brush is used for erasing strokes.

:TINT:            
  Tint.

  The brush is of type used for tinting strokes.

.. _rna-enum-brush-gpencil-types-items:

"""

import typing



"""


Render Operators
****************

:func:`opengl`

:func:`play_rendered_anim`

:func:`preset_add`

:func:`render`

:func:`shutter_curve_preset`

:func:`view_cancel`

:func:`view_show`

"""

import typing

def opengl(animation: bool = False, render_keyed_only: bool = False, sequencer: bool = False, write_still: bool = False, view_context: bool = True) -> None:

  """

  Take a snapshot of the active viewport

  """

  ...

def play_rendered_anim() -> None:

  """

  Play back rendered frames/movies using an external player

  :file:`startup/bl_operators/screen_play_rendered_anim.py\:64 <https://projects.blender.org/blender/blender/src/branch/main/scripts/startup/bl_operators/screen_play_rendered_anim.py#L64>`_

  """

  ...

def preset_add(name: str = '', remove_name: bool = False, remove_active: bool = False) -> None:

  """

  Add or remove a Render Preset

  :file:`startup/bl_operators/presets.py\:73 <https://projects.blender.org/blender/blender/src/branch/main/scripts/startup/bl_operators/presets.py#L73>`_

  """

  ...

def render(animation: bool = False, write_still: bool = False, use_viewport: bool = False, layer: str = '', scene: str = '') -> None:

  """

  Render active scene

  """

  ...

def shutter_curve_preset(shape: str = 'SMOOTH') -> None:

  """

  Set shutter curve

  """

  ...

def view_cancel() -> None:

  """

  Cancel show render view

  """

  ...

def view_show() -> None:

  """

  Toggle show render view

  """

  ...



"""


Freestyle Shaders (freestyle.shaders)
*************************************

This module contains stroke shaders used for creation of stylized
strokes.  It is also intended to be a collection of examples for
shader definition in Python.

User-defined stroke shaders inherit the
:class:`freestyle.types.StrokeShader` class.

:class:`BackboneStretcherShader`

:class:`BezierCurveShader`

:class:`BlenderTextureShader`

:class:`CalligraphicShader`

:class:`ColorNoiseShader`

:class:`ConstantColorShader`

:class:`ConstantThicknessShader`

:class:`ConstrainedIncreasingThicknessShader`

:class:`GuidingLinesShader`

:class:`IncreasingColorShader`

:class:`IncreasingThicknessShader`

:class:`PolygonalizationShader`

:class:`RoundCapShader`

:class:`SamplingShader`

:class:`SmoothingShader`

:class:`SpatialNoiseShader`

:class:`SquareCapShader`

:class:`StrokeTextureStepShader`

:class:`ThicknessNoiseShader`

:class:`TipRemoverShader`

:class:`py2DCurvatureColorShader`

:class:`pyBackboneStretcherNoCuspShader`

:class:`pyBackboneStretcherShader`

:class:`pyBluePrintCirclesShader`

:class:`pyBluePrintDirectedSquaresShader`

:class:`pyBluePrintEllipsesShader`

:class:`pyBluePrintSquaresShader`

:class:`pyConstantColorShader`

:class:`pyConstantThicknessShader`

:class:`pyConstrainedIncreasingThicknessShader`

:class:`pyDecreasingThicknessShader`

:class:`pyDepthDiscontinuityThicknessShader`

:class:`pyDiffusion2Shader`

:class:`pyFXSVaryingThicknessWithDensityShader`

:class:`pyGuidingLineShader`

:class:`pyHLRShader`

:class:`pyImportance2DThicknessShader`

:class:`pyImportance3DThicknessShader`

:class:`pyIncreasingColorShader`

:class:`pyIncreasingThicknessShader`

:class:`pyInterpolateColorShader`

:class:`pyLengthDependingBackboneStretcherShader`

:class:`pyMaterialColorShader`

:class:`pyModulateAlphaShader`

:class:`pyNonLinearVaryingThicknessShader`

:class:`pyPerlinNoise1DShader`

:class:`pyPerlinNoise2DShader`

:class:`pyRandomColorShader`

:class:`pySLERPThicknessShader`

:class:`pySamplingShader`

:class:`pySinusDisplacementShader`

:class:`pyTVertexRemoverShader`

:class:`pyTVertexThickenerShader`

:class:`pyTimeColorShader`

:class:`pyTipRemoverShader`

:class:`pyZDependingThicknessShader`

"""

import typing

import mathutils

import freestyle

class BackboneStretcherShader:

  """

  Class hierarchy: :class:`freestyle.types.StrokeShader` > :class:`BackboneStretcherShader`

  [Geometry shader]

  """

  def __init__(self, amount: float = 2.0) -> None:

    """

    Builds a BackboneStretcherShader object.

    """

    ...

  def shade(self, stroke: freestyle.types.Stroke) -> None:

    """

    Stretches the stroke at its two extremities and following the
respective directions: v(1)v(0) and v(n-1)v(n).

    """

    ...

class BezierCurveShader:

  """

  Class hierarchy: :class:`freestyle.types.StrokeShader` > :class:`BezierCurveShader`

  [Geometry shader]

  """

  def __init__(self, error: float = 4.0) -> None:

    """

    Builds a BezierCurveShader object.

    """

    ...

  def shade(self, stroke: freestyle.types.Stroke) -> None:

    """

    Transforms the stroke backbone geometry so that it corresponds to a
Bezier Curve approximation of the original backbone geometry.

    """

    ...

class BlenderTextureShader:

  """

  Class hierarchy: :class:`freestyle.types.StrokeShader` > :class:`BlenderTextureShader`

  [Texture shader]

  """

  def __init__(self, texture: typing.Union[bpy.types.LineStyleTextureSlot]) -> None:

    """

    Builds a BlenderTextureShader object.

    """

    ...

  def shade(self, stroke: freestyle.types.Stroke) -> None:

    """

    Assigns a blender texture slot to the stroke  shading in order to
simulate marks.

    """

    ...

class CalligraphicShader:

  """

  Class hierarchy: :class:`freestyle.types.StrokeShader` > :class:`CalligraphicShader`

  [Thickness Shader]

  """

  def __init__(self, thickness_min: float, thickness_max: float, orientation: mathutils.Vector, clamp: bool) -> None:

    """

    Builds a CalligraphicShader object.

    """

    ...

  def shade(self, stroke: freestyle.types.Stroke) -> None:

    """

    Assigns thicknesses to the stroke vertices so that the stroke looks
like made with a calligraphic tool, i.e. the stroke will be the
thickest in a main direction, and the thinnest in the direction
perpendicular to this one, and an interpolation in between.

    """

    ...

class ColorNoiseShader:

  """

  Class hierarchy: :class:`freestyle.types.StrokeShader` > :class:`ColorNoiseShader`

  [Color shader]

  """

  def __init__(self, amplitude: float, period: float) -> None:

    """

    Builds a ColorNoiseShader object.

    """

    ...

  def shade(self, stroke: freestyle.types.Stroke) -> None:

    """

    Shader to add noise to the stroke colors.

    """

    ...

class ConstantColorShader:

  """

  Class hierarchy: :class:`freestyle.types.StrokeShader` > :class:`ConstantColorShader`

  [Color shader]

  """

  def __init__(self, red: float, green: float, blue: float, alpha: float = 1.0) -> None:

    """

    Builds a ConstantColorShader object.

    """

    ...

  def shade(self, stroke: freestyle.types.Stroke) -> None:

    """

    Assigns a constant color to every vertex of the Stroke.

    """

    ...

class ConstantThicknessShader:

  """

  Class hierarchy: :class:`freestyle.types.StrokeShader` > :class:`ConstantThicknessShader`

  [Thickness shader]

  """

  def __init__(self, thickness: float) -> None:

    """

    Builds a ConstantThicknessShader object.

    """

    ...

  def shade(self, stroke: freestyle.types.Stroke) -> None:

    """

    Assigns an absolute constant thickness to every vertex of the Stroke.

    """

    ...

class ConstrainedIncreasingThicknessShader:

  """

  Class hierarchy: :class:`freestyle.types.StrokeShader` > :class:`ConstrainedIncreasingThicknessShader`

  [Thickness shader]

  """

  def __init__(self, thickness_min: float, thickness_max: float, ratio: float) -> None:

    """

    Builds a ConstrainedIncreasingThicknessShader object.

    """

    ...

  def shade(self, stroke: freestyle.types.Stroke) -> None:

    """

    Same as the :class:`IncreasingThicknessShader`, but here we allow
the user to control the thickness/length ratio so that we don't get
fat short lines.

    """

    ...

class GuidingLinesShader:

  """

  Class hierarchy: :class:`freestyle.types.StrokeShader` > :class:`GuidingLinesShader`

  [Geometry shader]

  """

  def __init__(self, offset: float) -> None:

    """

    Builds a GuidingLinesShader object.

    """

    ...

  def shade(self, stroke: freestyle.types.Stroke) -> None:

    """

    Shader to modify the Stroke geometry so that it corresponds to its
main direction line.  This shader must be used together with the
splitting operator using the curvature criterion. Indeed, the
precision of the approximation will depend on the size of the
stroke's pieces.  The bigger the pieces are, the rougher the
approximation is.

    """

    ...

class IncreasingColorShader:

  """

  Class hierarchy: :class:`freestyle.types.StrokeShader` > :class:`IncreasingColorShader`

  [Color shader]

  """

  def __init__(self, red_min: float, green_min: float, blue_min: float, alpha_min: float, red_max: float, green_max: float, blue_max: float, alpha_max: float) -> None:

    """

    Builds an IncreasingColorShader object.

    """

    ...

  def shade(self, stroke: freestyle.types.Stroke) -> None:

    """

    Assigns a varying color to the stroke.  The user specifies two
colors A and B.  The stroke color will change linearly from A to B
between the first and the last vertex.

    """

    ...

class IncreasingThicknessShader:

  """

  Class hierarchy: :class:`freestyle.types.StrokeShader` > :class:`IncreasingThicknessShader`

  [Thickness shader]

  """

  def __init__(self, thickness_A: float, thickness_B: float) -> None:

    """

    Builds an IncreasingThicknessShader object.

    """

    ...

  def shade(self, stroke: freestyle.types.Stroke) -> None:

    """

    Assigns thicknesses values such as the thickness increases from a
thickness value A to a thickness value B between the first vertex
to the midpoint vertex and then decreases from B to a A between
this midpoint vertex and the last vertex.  The thickness is
linearly interpolated from A to B.

    """

    ...

class PolygonalizationShader:

  """

  Class hierarchy: :class:`freestyle.types.StrokeShader` > :class:`PolygonalizationShader`

  [Geometry shader]

  """

  def __init__(self, error: float) -> None:

    """

    Builds a PolygonalizationShader object.

    """

    ...

  def shade(self, stroke: freestyle.types.Stroke) -> None:

    """

    Modifies the Stroke geometry so that it looks more "polygonal".
The basic idea is to start from the minimal stroke approximation
consisting in a line joining the first vertex to the last one and
to subdivide using the original stroke vertices until a certain
error is reached.

    """

    ...

class RoundCapShader:

  def round_cap_thickness(self, x: typing.Any) -> None:

    ...

  def shade(self, stroke: typing.Any) -> None:

    ...

class SamplingShader:

  """

  Class hierarchy: :class:`freestyle.types.StrokeShader` > :class:`SamplingShader`

  [Geometry shader]

  """

  def __init__(self, sampling: float) -> None:

    """

    Builds a SamplingShader object.

    """

    ...

  def shade(self, stroke: freestyle.types.Stroke) -> None:

    """

    Resamples the stroke.

    """

    ...

class SmoothingShader:

  """

  Class hierarchy: :class:`freestyle.types.StrokeShader` > :class:`SmoothingShader`

  [Geometry shader]

  """

  def __init__(self, num_iterations: int = 100, factor_point: float = 0.1, factor_curvature: float = 0.0, factor_curvature_difference: float = 0.2, aniso_point: float = 0.0, aniso_normal: float = 0.0, aniso_curvature: float = 0.0, carricature_factor: float = 1.0) -> None:

    """

    Builds a SmoothingShader object.

    """

    ...

  def shade(self, stroke: freestyle.types.Stroke) -> None:

    """

    Smooths the stroke by moving the vertices to make the stroke
smoother.  Uses curvature flow to converge towards a curve of
constant curvature.  The diffusion method we use is anisotropic to
prevent the diffusion across corners.

    """

    ...

class SpatialNoiseShader:

  """

  Class hierarchy: :class:`freestyle.types.StrokeShader` > :class:`SpatialNoiseShader`

  [Geometry shader]

  """

  def __init__(self, amount: float, scale: float, num_octaves: int, smooth: bool, pure_random: bool) -> None:

    """

    Builds a SpatialNoiseShader object.

    """

    ...

  def shade(self, stroke: freestyle.types.Stroke) -> None:

    """

    Spatial Noise stroke shader.  Moves the vertices to make the stroke
more noisy.

    """

    ...

class SquareCapShader:

  def shade(self, stroke: typing.Any) -> None:

    ...

class StrokeTextureStepShader:

  """

  Class hierarchy: :class:`freestyle.types.StrokeShader` > :class:`StrokeTextureStepShader`

  [Texture shader]

  """

  def __init__(self, step: float) -> None:

    """

    Builds a StrokeTextureStepShader object.

    """

    ...

  def shade(self, stroke: freestyle.types.Stroke) -> None:

    """

    Assigns a spacing factor to the texture coordinates of the Stroke.

    """

    ...

class ThicknessNoiseShader:

  """

  Class hierarchy: :class:`freestyle.types.StrokeShader` > :class:`ThicknessNoiseShader`

  [Thickness shader]

  """

  def __init__(self, amplitude: float, period: float) -> None:

    """

    Builds a ThicknessNoiseShader object.

    """

    ...

  def shade(self, stroke: freestyle.types.Stroke) -> None:

    """

    Adds some noise to the stroke thickness.

    """

    ...

class TipRemoverShader:

  """

  Class hierarchy: :class:`freestyle.types.StrokeShader` > :class:`TipRemoverShader`

  [Geometry shader]

  """

  def __init__(self, tip_length: float) -> None:

    """

    Builds a TipRemoverShader object.

    """

    ...

  def shade(self, stroke: freestyle.types.Stroke) -> None:

    """

    Removes the stroke's extremities.

    """

    ...

class py2DCurvatureColorShader:

  """

  Assigns a color (grayscale) to the stroke based on the curvature.
A higher curvature will yield a brighter color.

  """

  def shade(self, stroke: typing.Any) -> None:

    ...

class pyBackboneStretcherNoCuspShader:

  """

  Stretches the stroke's backbone, excluding cusp vertices (end junctions).

  """

  def shade(self, stroke: typing.Any) -> None:

    ...

class pyBackboneStretcherShader:

  """

  Stretches the stroke's backbone by a given length (in pixels).

  """

  def shade(self, stroke: typing.Any) -> None:

    ...

class pyBluePrintCirclesShader:

  """

  Draws the silhouette of the object as a circle.

  """

  def shade(self, stroke: typing.Any) -> None:

    ...

class pyBluePrintDirectedSquaresShader:

  """

  Replaces the stroke with a directed square.

  """

  def shade(self, stroke: typing.Any) -> None:

    ...

class pyBluePrintEllipsesShader:

  def shade(self, stroke: typing.Any) -> None:

    ...

class pyBluePrintSquaresShader:

  def shade(self, stroke: typing.Any) -> None:

    ...

class pyConstantColorShader:

  """

  Assigns a constant color to the stroke.

  """

  def shade(self, stroke: typing.Any) -> None:

    ...

class pyConstantThicknessShader:

  """

  Assigns a constant thickness along the stroke.

  """

  def shade(self, stroke: typing.Any) -> None:

    ...

class pyConstrainedIncreasingThicknessShader:

  """

  Increasingly thickens the stroke, constrained by a ratio of the
stroke's length.

  """

  def shade(self, stroke: typing.Any) -> None:

    ...

class pyDecreasingThicknessShader:

  """

  Inverse of pyIncreasingThicknessShader, decreasingly thickens the stroke.

  """

  def shade(self, stroke: typing.Any) -> None:

    ...

class pyDepthDiscontinuityThicknessShader:

  """

  Assigns a thickness to the stroke based on the stroke's distance
to the camera (Z-value).

  """

  def shade(self, stroke: typing.Any) -> None:

    ...

class pyDiffusion2Shader:

  """

  Iteratively adds an offset to the position of each stroke vertex
in the direction perpendicular to the stroke direction at the
point. The offset is scaled by the 2D curvature (i.e. how quickly
the stroke curve is) at the point.

  """

  def shade(self, stroke: typing.Any) -> None:

    ...

class pyFXSVaryingThicknessWithDensityShader:

  """

  Assigns thickness to a stroke based on the density of the diffuse map.

  """

  def shade(self, stroke: typing.Any) -> None:

    ...

class pyGuidingLineShader:

  def shade(self, stroke: typing.Any) -> None:

    ...

class pyHLRShader:

  """

  Controls visibility based upon the quantitative invisibility (QI)
based on hidden line removal (HLR).

  """

  def shade(self, stroke: typing.Any) -> None:

    ...

class pyImportance2DThicknessShader:

  """

  Assigns thickness based on distance to a given point in 2D space.
the thickness is inverted, so the vertices closest to the
specified point have the lowest thickness.

  """

  def shade(self, stroke: typing.Any) -> None:

    ...

class pyImportance3DThicknessShader:

  """

  Assigns thickness based on distance to a given point in 3D space.

  """

  def shade(self, stroke: typing.Any) -> None:

    ...

class pyIncreasingColorShader:

  """

  Fades from one color to another along the stroke.

  """

  def shade(self, stroke: typing.Any) -> None:

    ...

class pyIncreasingThicknessShader:

  """

  Increasingly thickens the stroke.

  """

  def shade(self, stroke: typing.Any) -> None:

    ...

class pyInterpolateColorShader:

  """

  Fades from one color to another and back.

  """

  def shade(self, stroke: typing.Any) -> None:

    ...

class pyLengthDependingBackboneStretcherShader:

  """

  Stretches the stroke's backbone proportional to the stroke's length
NOTE: you'll probably want an l somewhere between (0.5 - 0). A value that
is too high may yield unexpected results.

  """

  def shade(self, stroke: typing.Any) -> None:

    ...

class pyMaterialColorShader:

  """

  Assigns the color of the underlying material to the stroke.

  """

  def shade(self, stroke: typing.Any) -> None:

    ...

class pyModulateAlphaShader:

  """

  Limits the stroke's alpha between a min and max value.

  """

  def shade(self, stroke: typing.Any) -> None:

    ...

class pyNonLinearVaryingThicknessShader:

  """

  Assigns thickness to a stroke based on an exponential function.

  """

  def shade(self, stroke: typing.Any) -> None:

    ...

class pyPerlinNoise1DShader:

  """

  Displaces the stroke using the curvilinear abscissa.  This means
that lines with the same length and sampling interval will be
identically distorded.

  """

  def shade(self, stroke: typing.Any) -> None:

    ...

class pyPerlinNoise2DShader:

  """

  Displaces the stroke using the strokes coordinates.  This means
that in a scene no strokes will be distorded identically.

  More information on the noise shaders can be found at:
freestyleintegration.wordpress.com/2011/09/25/development-updates-on-september-25/

  """

  def shade(self, stroke: typing.Any) -> None:

    ...

class pyRandomColorShader:

  """

  Assigns a color to the stroke based on given seed.

  """

  def shade(self, stroke: typing.Any) -> None:

    ...

class pySLERPThicknessShader:

  """

  Assigns thickness to a stroke based on spherical linear interpolation.

  """

  def shade(self, stroke: typing.Any) -> None:

    ...

class pySamplingShader:

  """

  Resamples the stroke, which gives the stroke the amount of
vertices specified.

  """

  def shade(self, stroke: typing.Any) -> None:

    ...

class pySinusDisplacementShader:

  """

  Displaces the stroke in the shape of a sine wave.

  """

  def shade(self, stroke: typing.Any) -> None:

    ...

class pyTVertexRemoverShader:

  """

  Removes t-vertices from the stroke.

  """

  def shade(self, stroke: typing.Any) -> None:

    ...

class pyTVertexThickenerShader:

  """

  Thickens TVertices (visual intersections between two edges).

  """

  def shade(self, stroke: typing.Any) -> None:

    ...

class pyTimeColorShader:

  """

  Assigns a grayscale value that increases for every vertex.
The brightness will increase along the stroke.

  """

  def shade(self, stroke: typing.Any) -> None:

    ...

class pyTipRemoverShader:

  """

  Removes the tips of the stroke.

  Undocumented

  """

  def shade(self, stroke: typing.Any) -> None:

    ...

class pyZDependingThicknessShader:

  """

  Assigns thickness based on an object's local Z depth (point
closest to camera is 1, point furthest from camera is zero).

  """

  def shade(self, stroke: typing.Any) -> None:

    ...



"""


Property Subtype Number Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:PIXEL:           
  Pixel.

:UNSIGNED:        
  Unsigned.

:PERCENTAGE:      
  Percentage.

:FACTOR:          
  Factor.

:ANGLE:           
  Angle.

:TIME:            
  Time (Scene Relative).

  Time specified in frames, converted to seconds based on scene frame rate.

:TIME_ABSOLUTE:   
  Time (Absolute).

  Time specified in seconds, independent of the scene.

:DISTANCE:        
  Distance.

:DISTANCE_CAMERA: 
  Camera Distance.

:POWER:           
  Power.

:TEMPERATURE:     
  Temperature.

:NONE:            
  None.

.. _rna-enum-property-subtype-number-items:

"""

import typing



"""


Freestyle Functions (freestyle.functions)
*****************************************

This module contains functions operating on vertices (0D elements) and
polylines (1D elements).  The module is also intended to be a
collection of examples for function definition in Python.

User-defined functions inherit one of the following base classes,
depending on the object type (0D or 1D) to operate on and the return
value type:

* :class:`freestyle.types.UnaryFunction0DDouble`

* :class:`freestyle.types.UnaryFunction0DEdgeNature`

* :class:`freestyle.types.UnaryFunction0DFloat`

* :class:`freestyle.types.UnaryFunction0DId`

* :class:`freestyle.types.UnaryFunction0DMaterial`

* :class:`freestyle.types.UnaryFunction0DUnsigned`

* :class:`freestyle.types.UnaryFunction0DVec2f`

* :class:`freestyle.types.UnaryFunction0DVec3f`

* :class:`freestyle.types.UnaryFunction0DVectorViewShape`

* :class:`freestyle.types.UnaryFunction0DViewShape`

* :class:`freestyle.types.UnaryFunction1DDouble`

* :class:`freestyle.types.UnaryFunction1DEdgeNature`

* :class:`freestyle.types.UnaryFunction1DFloat`

* :class:`freestyle.types.UnaryFunction1DUnsigned`

* :class:`freestyle.types.UnaryFunction1DVec2f`

* :class:`freestyle.types.UnaryFunction1DVec3f`

* :class:`freestyle.types.UnaryFunction1DVectorViewShape`

* :class:`freestyle.types.UnaryFunction1DVoid`

:class:`ChainingTimeStampF1D`

:class:`Curvature2DAngleF0D`

:class:`Curvature2DAngleF1D`

:class:`CurveMaterialF0D`

:class:`CurveNatureF0D`

:class:`CurveNatureF1D`

:class:`DensityF0D`

:class:`DensityF1D`

:class:`GetCompleteViewMapDensityF1D`

:class:`GetCurvilinearAbscissaF0D`

:class:`GetDirectionalViewMapDensityF1D`

:class:`GetOccludeeF0D`

:class:`GetOccludeeF1D`

:class:`GetOccludersF0D`

:class:`GetOccludersF1D`

:class:`GetParameterF0D`

:class:`GetProjectedXF0D`

:class:`GetProjectedXF1D`

:class:`GetProjectedYF0D`

:class:`GetProjectedYF1D`

:class:`GetProjectedZF0D`

:class:`GetProjectedZF1D`

:class:`GetShapeF0D`

:class:`GetShapeF1D`

:class:`GetSteerableViewMapDensityF1D`

:class:`GetViewMapGradientNormF0D`

:class:`GetViewMapGradientNormF1D`

:class:`GetXF0D`

:class:`GetXF1D`

:class:`GetYF0D`

:class:`GetYF1D`

:class:`GetZF0D`

:class:`GetZF1D`

:class:`IncrementChainingTimeStampF1D`

:class:`LocalAverageDepthF0D`

:class:`LocalAverageDepthF1D`

:class:`MaterialF0D`

:class:`Normal2DF0D`

:class:`Normal2DF1D`

:class:`Orientation2DF1D`

:class:`Orientation3DF1D`

:class:`QuantitativeInvisibilityF0D`

:class:`QuantitativeInvisibilityF1D`

:class:`ReadCompleteViewMapPixelF0D`

:class:`ReadMapPixelF0D`

:class:`ReadSteerableViewMapPixelF0D`

:class:`ShapeIdF0D`

:class:`TimeStampF1D`

:class:`VertexOrientation2DF0D`

:class:`VertexOrientation3DF0D`

:class:`ZDiscontinuityF0D`

:class:`ZDiscontinuityF1D`

:class:`pyCurvilinearLengthF0D`

:class:`pyDensityAnisotropyF0D`

:class:`pyDensityAnisotropyF1D`

:class:`pyGetInverseProjectedZF1D`

:class:`pyGetSquareInverseProjectedZF1D`

:class:`pyInverseCurvature2DAngleF0D`

:class:`pyViewMapGradientNormF0D`

:class:`pyViewMapGradientNormF1D`

:class:`pyViewMapGradientVectorF0D`

"""

import typing

import mathutils

import freestyle

class ChainingTimeStampF1D:

  """

  Class hierarchy: :class:`freestyle.types.UnaryFunction1D` > :class:`freestyle.types.UnaryFunction1DVoid` > :class:`ChainingTimeStampF1D`

  """

  def __init__(self) -> None:

    """

    Builds a ChainingTimeStampF1D object.

    """

    ...

  def __call__(self, inter: freestyle.types.Interface1D) -> None:

    """

    Sets the chaining time stamp of the Interface1D.

    """

    ...

class Curvature2DAngleF0D:

  """

  Class hierarchy: :class:`freestyle.types.UnaryFunction0D` > :class:`freestyle.types.UnaryFunction0DDouble` > :class:`Curvature2DAngleF0D`

  """

  def __init__(self) -> None:

    """

    Builds a Curvature2DAngleF0D object.

    """

    ...

  def __call__(self, it: freestyle.types.Interface0DIterator) -> float:

    """

    Returns a real value giving the 2D curvature (as an angle) of the 1D
element to which the :class:`freestyle.types.Interface0D` pointed by
the Interface0DIterator belongs.  The 2D curvature is evaluated at the
Interface0D.

    """

    ...

class Curvature2DAngleF1D:

  """

  Class hierarchy: :class:`freestyle.types.UnaryFunction1D` > :class:`freestyle.types.UnaryFunction1DDouble` > :class:`Curvature2DAngleF1D`

  """

  def __init__(self, integration_type: freestyle.types.IntegrationType = IntegrationType.MEAN) -> None:

    """

    Builds a Curvature2DAngleF1D object.

    """

    ...

  def __call__(self, inter: freestyle.types.Interface1D) -> float:

    """

    Returns the 2D curvature as an angle for an Interface1D.

    """

    ...

class CurveMaterialF0D:

  """

  A replacement of the built-in MaterialF0D for stroke creation.
MaterialF0D does not work with Curves and Strokes.  Line color
priority is used to pick one of the two materials at material
boundaries.

  Notes: expects instances of CurvePoint to be iterated over
    can return None if no fedge can be found

  """

  ...

class CurveNatureF0D:

  """

  Class hierarchy: :class:`freestyle.types.UnaryFunction0D` > :class:`freestyle.types.UnaryFunction0DEdgeNature` > :class:`CurveNatureF0D`

  """

  def __init__(self) -> None:

    """

    Builds a CurveNatureF0D object.

    """

    ...

  def __call__(self, it: freestyle.types.Interface0DIterator) -> freestyle.types.Nature:

    """

    Returns the :class:`freestyle.types.Nature` of the 1D element the
Interface0D pointed by the Interface0DIterator belongs to.

    """

    ...

class CurveNatureF1D:

  """

  Class hierarchy: :class:`freestyle.types.UnaryFunction1D` > :class:`freestyle.types.UnaryFunction1DEdgeNature` > :class:`CurveNatureF1D`

  """

  def __init__(self, integration_type: freestyle.types.IntegrationType = IntegrationType.MEAN) -> None:

    """

    Builds a CurveNatureF1D object.

    """

    ...

  def __call__(self, inter: freestyle.types.Interface1D) -> freestyle.types.Nature:

    """

    Returns the nature of the Interface1D (silhouette, ridge, crease, and
so on).  Except if the Interface1D is a
:class:`freestyle.types.ViewEdge`, this result might be ambiguous.
Indeed, the Interface1D might result from the gathering of several 1D
elements, each one being of a different nature.  An integration
method, such as the MEAN, might give, in this case, irrelevant
results.

    """

    ...

class DensityF0D:

  """

  Class hierarchy: :class:`freestyle.types.UnaryFunction0D` > :class:`freestyle.types.UnaryFunction0DDouble` > :class:`DensityF0D`

  """

  def __init__(self, sigma: float = 2.0) -> None:

    """

    Builds a DensityF0D object.

    """

    ...

  def __call__(self, it: freestyle.types.Interface0DIterator) -> float:

    """

    Returns the density of the (result) image evaluated at the
:class:`freestyle.types.Interface0D` pointed by the
Interface0DIterator. This density is evaluated using a pixels square
window around the evaluation point and integrating these values using
a gaussian.

    """

    ...

class DensityF1D:

  """

  Class hierarchy: :class:`freestyle.types.UnaryFunction1D` > :class:`freestyle.types.UnaryFunction1DDouble` > :class:`DensityF1D`

  """

  def __init__(self, sigma: float = 2.0, integration_type: freestyle.types.IntegrationType = IntegrationType.MEAN, sampling: float = 2.0) -> None:

    """

    Builds a DensityF1D object.

    """

    ...

  def __call__(self, inter: freestyle.types.Interface1D) -> float:

    """

    Returns the density evaluated for an Interface1D. The density is
evaluated for a set of points along the Interface1D (using the
:class:`freestyle.functions.DensityF0D` functor) with a user-defined
sampling and then integrated into a single value using a user-defined
integration method.

    """

    ...

class GetCompleteViewMapDensityF1D:

  """

  Class hierarchy: :class:`freestyle.types.UnaryFunction1D` > :class:`freestyle.types.UnaryFunction1DDouble` > :class:`GetCompleteViewMapDensityF1D`

  """

  def __init__(self, level: int, integration_type: freestyle.types.IntegrationType = IntegrationType.MEAN, sampling: float = 2.0) -> None:

    """

    Builds a GetCompleteViewMapDensityF1D object.

    """

    ...

  def __call__(self, inter: freestyle.types.Interface1D) -> float:

    """

    Returns the density evaluated for an Interface1D in the complete
viewmap image.  The density is evaluated for a set of points along the
Interface1D (using the
:class:`freestyle.functions.ReadCompleteViewMapPixelF0D` functor) and
then integrated into a single value using a user-defined integration
method.

    """

    ...

class GetCurvilinearAbscissaF0D:

  """

  Class hierarchy: :class:`freestyle.types.UnaryFunction0D` > :class:`freestyle.types.UnaryFunction0DFloat` > :class:`GetCurvilinearAbscissaF0D`

  """

  def __init__(self) -> None:

    """

    Builds a GetCurvilinearAbscissaF0D object.

    """

    ...

  def __call__(self, it: freestyle.types.Interface0DIterator) -> float:

    """

    Returns the curvilinear abscissa of the
:class:`freestyle.types.Interface0D` pointed by the
Interface0DIterator in the context of its 1D element.

    """

    ...

class GetDirectionalViewMapDensityF1D:

  """

  Class hierarchy: :class:`freestyle.types.UnaryFunction1D` > :class:`freestyle.types.UnaryFunction1DDouble` > :class:`GetDirectionalViewMapDensityF1D`

  """

  def __init__(self, orientation: int, level: int, integration_type: freestyle.types.IntegrationType = IntegrationType.MEAN, sampling: float = 2.0) -> None:

    """

    Builds a GetDirectionalViewMapDensityF1D object.

    """

    ...

  def __call__(self, inter: freestyle.types.Interface1D) -> float:

    """

    Returns the density evaluated for an Interface1D in of the steerable
viewmaps image.  The direction telling which Directional map to choose
is explicitly specified by the user.  The density is evaluated for a
set of points along the Interface1D (using the
:class:`freestyle.functions.ReadSteerableViewMapPixelF0D` functor) and
then integrated into a single value using a user-defined integration
method.

    """

    ...

class GetOccludeeF0D:

  """

  Class hierarchy: :class:`freestyle.types.UnaryFunction0D` > :class:`freestyle.types.UnaryFunction0DViewShape` > :class:`GetOccludeeF0D`

  """

  def __init__(self) -> None:

    """

    Builds a GetOccludeeF0D object.

    """

    ...

  def __call__(self, it: freestyle.types.Interface0DIterator) -> freestyle.types.ViewShape:

    """

    Returns the :class:`freestyle.types.ViewShape` that the Interface0D
pointed by the Interface0DIterator occludes.

    """

    ...

class GetOccludeeF1D:

  """

  Class hierarchy: :class:`freestyle.types.UnaryFunction1D` > :class:`freestyle.types.UnaryFunction1DVectorViewShape` > :class:`GetOccludeeF1D`

  """

  def __init__(self) -> None:

    """

    Builds a GetOccludeeF1D object.

    """

    ...

  def __call__(self, inter: freestyle.types.Interface1D) -> typing.List[freestyle.types.ViewShape]:

    """

    Returns a list of occluded shapes covered by this Interface1D.

    """

    ...

class GetOccludersF0D:

  """

  Class hierarchy: :class:`freestyle.types.UnaryFunction0D` > :class:`freestyle.types.UnaryFunction0DVectorViewShape` > :class:`GetOccludersF0D`

  """

  def __init__(self) -> None:

    """

    Builds a GetOccludersF0D object.

    """

    ...

  def __call__(self, it: freestyle.types.Interface0DIterator) -> typing.List[freestyle.types.ViewShape]:

    """

    Returns a list of :class:`freestyle.types.ViewShape` objects occluding the
:class:`freestyle.types.Interface0D` pointed by the Interface0DIterator.

    """

    ...

class GetOccludersF1D:

  """

  Class hierarchy: :class:`freestyle.types.UnaryFunction1D` > :class:`freestyle.types.UnaryFunction1DVectorViewShape` > :class:`GetOccludersF1D`

  """

  def __init__(self) -> None:

    """

    Builds a GetOccludersF1D object.

    """

    ...

  def __call__(self, inter: freestyle.types.Interface1D) -> typing.List[freestyle.types.ViewShape]:

    """

    Returns a list of occluding shapes that cover this Interface1D.

    """

    ...

class GetParameterF0D:

  """

  Class hierarchy: :class:`freestyle.types.UnaryFunction0D` > :class:`freestyle.types.UnaryFunction0DFloat` > :class:`GetParameterF0D`

  """

  def __init__(self) -> None:

    """

    Builds a GetParameterF0D object.

    """

    ...

  def __call__(self, it: freestyle.types.Interface0DIterator) -> float:

    """

    Returns the parameter of the :class:`freestyle.types.Interface0D`
pointed by the Interface0DIterator in the context of its 1D element.

    """

    ...

class GetProjectedXF0D:

  """

  Class hierarchy: :class:`freestyle.types.UnaryFunction0D` > :class:`freestyle.types.UnaryFunction0DDouble` > :class:`GetProjectedXF0D`

  """

  def __init__(self) -> None:

    """

    Builds a GetProjectedXF0D object.

    """

    ...

  def __call__(self, it: freestyle.types.Interface0DIterator) -> float:

    """

    Returns the X 3D projected coordinate of the :class:`freestyle.types.Interface0D`
pointed by the Interface0DIterator.

    """

    ...

class GetProjectedXF1D:

  """

  Class hierarchy: :class:`freestyle.types.UnaryFunction1D` > :class:`freestyle.types.UnaryFunction1DDouble` > :class:`GetProjectedXF1D`

  """

  def __init__(self, integration_type: freestyle.types.IntegrationType = IntegrationType.MEAN) -> None:

    """

    Builds a GetProjectedXF1D object.

    """

    ...

  def __call__(self, inter: freestyle.types.Interface1D) -> float:

    """

    Returns the projected X 3D coordinate of an Interface1D.

    """

    ...

class GetProjectedYF0D:

  """

  Class hierarchy: :class:`freestyle.types.UnaryFunction0D` > :class:`freestyle.types.UnaryFunction0DDouble` > :class:`GetProjectedYF0D`

  """

  def __init__(self) -> None:

    """

    Builds a GetProjectedYF0D object.

    """

    ...

  def __call__(self, it: freestyle.types.Interface0DIterator) -> float:

    """

    Returns the Y 3D projected coordinate of the :class:`freestyle.types.Interface0D`
pointed by the Interface0DIterator.

    """

    ...

class GetProjectedYF1D:

  """

  Class hierarchy: :class:`freestyle.types.UnaryFunction1D` > :class:`freestyle.types.UnaryFunction1DDouble` > :class:`GetProjectedYF1D`

  """

  def __init__(self, integration_type: freestyle.types.IntegrationType = IntegrationType.MEAN) -> None:

    """

    Builds a GetProjectedYF1D object.

    """

    ...

  def __call__(self, inter: freestyle.types.Interface1D) -> float:

    """

    Returns the projected Y 3D coordinate of an Interface1D.

    """

    ...

class GetProjectedZF0D:

  """

  Class hierarchy: :class:`freestyle.types.UnaryFunction0D` > :class:`freestyle.types.UnaryFunction0DDouble` > :class:`GetProjectedZF0D`

  """

  def __init__(self) -> None:

    """

    Builds a GetProjectedZF0D object.

    """

    ...

  def __call__(self, it: freestyle.types.Interface0DIterator) -> float:

    """

    Returns the Z 3D projected coordinate of the :class:`freestyle.types.Interface0D`
pointed by the Interface0DIterator.

    """

    ...

class GetProjectedZF1D:

  """

  Class hierarchy: :class:`freestyle.types.UnaryFunction1D` > :class:`freestyle.types.UnaryFunction1DDouble` > :class:`GetProjectedZF1D`

  """

  def __init__(self, integration_type: freestyle.types.IntegrationType = IntegrationType.MEAN) -> None:

    """

    Builds a GetProjectedZF1D object.

    """

    ...

  def __call__(self, inter: freestyle.types.Interface1D) -> float:

    """

    Returns the projected Z 3D coordinate of an Interface1D.

    """

    ...

class GetShapeF0D:

  """

  Class hierarchy: :class:`freestyle.types.UnaryFunction0D` > :class:`freestyle.types.UnaryFunction0DViewShape` > :class:`GetShapeF0D`

  """

  def __init__(self) -> None:

    """

    Builds a GetShapeF0D object.

    """

    ...

  def __call__(self, it: freestyle.types.Interface0DIterator) -> freestyle.types.ViewShape:

    """

    Returns the :class:`freestyle.types.ViewShape` containing the
Interface0D pointed by the Interface0DIterator.

    """

    ...

class GetShapeF1D:

  """

  Class hierarchy: :class:`freestyle.types.UnaryFunction1D` > :class:`freestyle.types.UnaryFunction1DVectorViewShape` > :class:`GetShapeF1D`

  """

  def __init__(self) -> None:

    """

    Builds a GetShapeF1D object.

    """

    ...

  def __call__(self, inter: freestyle.types.Interface1D) -> typing.List[freestyle.types.ViewShape]:

    """

    Returns a list of shapes covered by this Interface1D.

    """

    ...

class GetSteerableViewMapDensityF1D:

  """

  Class hierarchy: :class:`freestyle.types.UnaryFunction1D` > :class:`freestyle.types.UnaryFunction1DDouble` > :class:`GetSteerableViewMapDensityF1D`

  """

  def __init__(self, level: int, integration_type: freestyle.types.IntegrationType = IntegrationType.MEAN, sampling: float = 2.0) -> None:

    """

    Builds a GetSteerableViewMapDensityF1D object.

    """

    ...

  def __call__(self, inter: freestyle.types.Interface1D) -> float:

    """

    Returns the density of the ViewMap for a given Interface1D.  The
density of each :class:`freestyle.types.FEdge` is evaluated in the
proper steerable :class:`freestyle.types.ViewMap` depending on its
orientation.

    """

    ...

class GetViewMapGradientNormF0D:

  """

  Class hierarchy: :class:`freestyle.types.UnaryFunction0D` > :class:`freestyle.types.UnaryFunction0DFloat` > :class:`GetViewMapGradientNormF0D`

  """

  def __init__(self, level: int) -> None:

    """

    Builds a GetViewMapGradientNormF0D object.

    """

    ...

  def __call__(self, it: freestyle.types.Interface0DIterator) -> float:

    """

    Returns the norm of the gradient of the global viewmap density
image.

    """

    ...

class GetViewMapGradientNormF1D:

  """

  Class hierarchy: :class:`freestyle.types.UnaryFunction1D` > :class:`freestyle.types.UnaryFunction1DDouble` > :class:`GetViewMapGradientNormF1D`

  """

  def __init__(self, level: int, integration_type: freestyle.types.IntegrationType = IntegrationType.MEAN, sampling: float = 2.0) -> None:

    """

    Builds a GetViewMapGradientNormF1D object.

    """

    ...

  def __call__(self, inter: freestyle.types.Interface1D) -> float:

    """

    Returns the density of the ViewMap for a given Interface1D.  The
density of each :class:`freestyle.types.FEdge` is evaluated in the
proper steerable :class:`freestyle.types.ViewMap` depending on its
orientation.

    """

    ...

class GetXF0D:

  """

  Class hierarchy: :class:`freestyle.types.UnaryFunction0D` > :class:`freestyle.types.UnaryFunction0DDouble` > :class:`GetXF0D`

  """

  def __init__(self) -> None:

    """

    Builds a GetXF0D object.

    """

    ...

  def __call__(self, it: freestyle.types.Interface0DIterator) -> float:

    """

    Returns the X 3D coordinate of the :class:`freestyle.types.Interface0D` pointed by
the Interface0DIterator.

    """

    ...

class GetXF1D:

  """

  Class hierarchy: :class:`freestyle.types.UnaryFunction1D` > :class:`freestyle.types.UnaryFunction1DDouble` > :class:`GetXF1D`

  """

  def __init__(self, integration_type: freestyle.types.IntegrationType = IntegrationType.MEAN) -> None:

    """

    Builds a GetXF1D object.

    """

    ...

  def __call__(self, inter: freestyle.types.Interface1D) -> float:

    """

    Returns the X 3D coordinate of an Interface1D.

    """

    ...

class GetYF0D:

  """

  Class hierarchy: :class:`freestyle.types.UnaryFunction0D` > :class:`freestyle.types.UnaryFunction0DDouble` > :class:`GetYF0D`

  """

  def __init__(self) -> None:

    """

    Builds a GetYF0D object.

    """

    ...

  def __call__(self, it: freestyle.types.Interface0DIterator) -> float:

    """

    Returns the Y 3D coordinate of the :class:`freestyle.types.Interface0D` pointed by
the Interface0DIterator.

    """

    ...

class GetYF1D:

  """

  Class hierarchy: :class:`freestyle.types.UnaryFunction1D` > :class:`freestyle.types.UnaryFunction1DDouble` > :class:`GetYF1D`

  """

  def __init__(self, integration_type: freestyle.types.IntegrationType = IntegrationType.MEAN) -> None:

    """

    Builds a GetYF1D object.

    """

    ...

  def __call__(self, inter: freestyle.types.Interface1D) -> float:

    """

    Returns the Y 3D coordinate of an Interface1D.

    """

    ...

class GetZF0D:

  """

  Class hierarchy: :class:`freestyle.types.UnaryFunction0D` > :class:`freestyle.types.UnaryFunction0DDouble` > :class:`GetZF0D`

  """

  def __init__(self) -> None:

    """

    Builds a GetZF0D object.

    """

    ...

  def __call__(self, it: freestyle.types.Interface0DIterator) -> float:

    """

    Returns the Z 3D coordinate of the :class:`freestyle.types.Interface0D` pointed by
the Interface0DIterator.

    """

    ...

class GetZF1D:

  """

  Class hierarchy: :class:`freestyle.types.UnaryFunction1D` > :class:`freestyle.types.UnaryFunction1DDouble` > :class:`GetZF1D`

  """

  def __init__(self, integration_type: freestyle.types.IntegrationType = IntegrationType.MEAN) -> None:

    """

    Builds a GetZF1D object.

    """

    ...

  def __call__(self, inter: freestyle.types.Interface1D) -> float:

    """

    Returns the Z 3D coordinate of an Interface1D.

    """

    ...

class IncrementChainingTimeStampF1D:

  """

  Class hierarchy: :class:`freestyle.types.UnaryFunction1D` > :class:`freestyle.types.UnaryFunction1DVoid` > :class:`IncrementChainingTimeStampF1D`

  """

  def __init__(self) -> None:

    """

    Builds an IncrementChainingTimeStampF1D object.

    """

    ...

  def __call__(self, inter: freestyle.types.Interface1D) -> None:

    """

    Increments the chaining time stamp of the Interface1D.

    """

    ...

class LocalAverageDepthF0D:

  """

  Class hierarchy: :class:`freestyle.types.UnaryFunction0D` > :class:`freestyle.types.UnaryFunction0DDouble` > :class:`LocalAverageDepthF0D`

  """

  def __init__(self, mask_size: float = 5.0) -> None:

    """

    Builds a LocalAverageDepthF0D object.

    """

    ...

  def __call__(self, it: freestyle.types.Interface0DIterator) -> float:

    """

    Returns the average depth around the
:class:`freestyle.types.Interface0D` pointed by the
Interface0DIterator.  The result is obtained by querying the depth
buffer on a window around that point.

    """

    ...

class LocalAverageDepthF1D:

  """

  Class hierarchy: :class:`freestyle.types.UnaryFunction1D` > :class:`freestyle.types.UnaryFunction1DDouble` > :class:`LocalAverageDepthF1D`

  """

  def __init__(self, sigma: float, integration_type: freestyle.types.IntegrationType = IntegrationType.MEAN) -> None:

    """

    Builds a LocalAverageDepthF1D object.

    """

    ...

  def __call__(self, inter: freestyle.types.Interface1D) -> float:

    """

    Returns the average depth evaluated for an Interface1D.  The average
depth is evaluated for a set of points along the Interface1D (using
the :class:`freestyle.functions.LocalAverageDepthF0D` functor) with a
user-defined sampling and then integrated into a single value using a
user-defined integration method.

    """

    ...

class MaterialF0D:

  """

  Class hierarchy: :class:`freestyle.types.UnaryFunction0D` > :class:`freestyle.types.UnaryFunction0DMaterial` > :class:`MaterialF0D`

  """

  def __init__(self) -> None:

    """

    Builds a MaterialF0D object.

    """

    ...

  def __call__(self, it: freestyle.types.Interface0DIterator) -> freestyle.types.Material:

    """

    Returns the material of the object evaluated at the
:class:`freestyle.types.Interface0D` pointed by the
Interface0DIterator.  This evaluation can be ambiguous (in the case of
a :class:`freestyle.types.TVertex` for example.  This functor tries to
remove this ambiguity using the context offered by the 1D element to
which the Interface0DIterator belongs to and by arbitrary choosing the
material of the face that lies on its left when following the 1D
element if there are two different materials on each side of the
point.  However, there still can be problematic cases, and the user
willing to deal with this cases in a specific way should implement its
own getMaterial functor.

    """

    ...

class Normal2DF0D:

  """

  Class hierarchy: :class:`freestyle.types.UnaryFunction0D` > :class:`freestyle.types.UnaryFunction0DVec2f` > :class:`Normal2DF0D`

  """

  def __init__(self) -> None:

    """

    Builds a Normal2DF0D object.

    """

    ...

  def __call__(self, it: freestyle.types.Interface0DIterator) -> mathutils.Vector:

    """

    Returns a two-dimensional vector giving the normalized 2D normal to
the 1D element to which the :class:`freestyle.types.Interface0D`
pointed by the Interface0DIterator belongs.  The normal is evaluated
at the pointed Interface0D.

    """

    ...

class Normal2DF1D:

  """

  Class hierarchy: :class:`freestyle.types.UnaryFunction1D` > :class:`freestyle.types.UnaryFunction1DVec2f` > :class:`Normal2DF1D`

  """

  def __init__(self, integration_type: freestyle.types.IntegrationType = IntegrationType.MEAN) -> None:

    """

    Builds a Normal2DF1D object.

    """

    ...

  def __call__(self, inter: freestyle.types.Interface1D) -> mathutils.Vector:

    """

    Returns the 2D normal for the Interface1D.

    """

    ...

class Orientation2DF1D:

  """

  Class hierarchy: :class:`freestyle.types.UnaryFunction1D` > :class:`freestyle.types.UnaryFunction1DVec2f` > :class:`Orientation2DF1D`

  """

  def __init__(self, integration_type: freestyle.types.IntegrationType = IntegrationType.MEAN) -> None:

    """

    Builds an Orientation2DF1D object.

    """

    ...

  def __call__(self, inter: freestyle.types.Interface1D) -> mathutils.Vector:

    """

    Returns the 2D orientation of the Interface1D.

    """

    ...

class Orientation3DF1D:

  """

  Class hierarchy: :class:`freestyle.types.UnaryFunction1D` > :class:`freestyle.types.UnaryFunction1DVec3f` > :class:`Orientation3DF1D`

  """

  def __init__(self, integration_type: freestyle.types.IntegrationType = IntegrationType.MEAN) -> None:

    """

    Builds an Orientation3DF1D object.

    """

    ...

  def __call__(self, inter: freestyle.types.Interface1D) -> mathutils.Vector:

    """

    Returns the 3D orientation of the Interface1D.

    """

    ...

class QuantitativeInvisibilityF0D:

  """

  Class hierarchy: :class:`freestyle.types.UnaryFunction0D` > :class:`freestyle.types.UnaryFunction0DUnsigned` > :class:`QuantitativeInvisibilityF0D`

  """

  def __init__(self) -> None:

    """

    Builds a QuantitativeInvisibilityF0D object.

    """

    ...

  def __call__(self, it: freestyle.types.Interface0DIterator) -> int:

    """

    Returns the quantitative invisibility of the
:class:`freestyle.types.Interface0D` pointed by the
Interface0DIterator.  This evaluation can be ambiguous (in the case of
a :class:`freestyle.types.TVertex` for example).  This functor tries
to remove this ambiguity using the context offered by the 1D element
to which the Interface0D belongs to.  However, there still can be
problematic cases, and the user willing to deal with this cases in a
specific way should implement its own getQIF0D functor.

    """

    ...

class QuantitativeInvisibilityF1D:

  """

  Class hierarchy: :class:`freestyle.types.UnaryFunction1D` > :class:`freestyle.types.UnaryFunction1DUnsigned` > :class:`QuantitativeInvisibilityF1D`

  """

  def __init__(self, integration_type: freestyle.types.IntegrationType = IntegrationType.MEAN) -> None:

    """

    Builds a QuantitativeInvisibilityF1D object.

    """

    ...

  def __call__(self, inter: freestyle.types.Interface1D) -> int:

    """

    Returns the Quantitative Invisibility of an Interface1D element. If
the Interface1D is a :class:`freestyle.types.ViewEdge`, then there is
no ambiguity concerning the result.  But, if the Interface1D results
of a chaining (chain, stroke), then it might be made of several 1D
elements of different Quantitative Invisibilities.

    """

    ...

class ReadCompleteViewMapPixelF0D:

  """

  Class hierarchy: :class:`freestyle.types.UnaryFunction0D` > :class:`freestyle.types.UnaryFunction0DFloat` > :class:`ReadCompleteViewMapPixelF0D`

  """

  def __init__(self, level: int) -> None:

    """

    Builds a ReadCompleteViewMapPixelF0D object.

    """

    ...

  def __call__(self, it: freestyle.types.Interface0DIterator) -> float:

    """

    Reads a pixel in one of the level of the complete viewmap.

    """

    ...

class ReadMapPixelF0D:

  """

  Class hierarchy: :class:`freestyle.types.UnaryFunction0D` > :class:`freestyle.types.UnaryFunction0DFloat` > :class:`ReadMapPixelF0D`

  """

  def __init__(self, map_name: str, level: int) -> None:

    """

    Builds a ReadMapPixelF0D object.

    """

    ...

  def __call__(self, it: freestyle.types.Interface0DIterator) -> float:

    """

    Reads a pixel in a map.

    """

    ...

class ReadSteerableViewMapPixelF0D:

  """

  Class hierarchy: :class:`freestyle.types.UnaryFunction0D` > :class:`freestyle.types.UnaryFunction0DFloat` > :class:`ReadSteerableViewMapPixelF0D`

  """

  def __init__(self, orientation: int, level: int) -> None:

    """

    Builds a ReadSteerableViewMapPixelF0D object.

    """

    ...

  def __call__(self, it: freestyle.types.Interface0DIterator) -> float:

    """

    Reads a pixel in one of the level of one of the steerable viewmaps.

    """

    ...

class ShapeIdF0D:

  """

  Class hierarchy: :class:`freestyle.types.UnaryFunction0D` > :class:`freestyle.types.UnaryFunction0DId` > :class:`ShapeIdF0D`

  """

  def __init__(self) -> None:

    """

    Builds a ShapeIdF0D object.

    """

    ...

  def __call__(self, it: freestyle.types.Interface0DIterator) -> freestyle.types.Id:

    """

    Returns the :class:`freestyle.types.Id` of the Shape the
:class:`freestyle.types.Interface0D` pointed by the
Interface0DIterator belongs to. This evaluation can be ambiguous (in
the case of a :class:`freestyle.types.TVertex` for example).  This
functor tries to remove this ambiguity using the context offered by
the 1D element to which the Interface0DIterator belongs to. However,
there still can be problematic cases, and the user willing to deal
with this cases in a specific way should implement its own
getShapeIdF0D functor.

    """

    ...

class TimeStampF1D:

  """

  Class hierarchy: :class:`freestyle.types.UnaryFunction1D` > :class:`freestyle.types.UnaryFunction1DVoid` > :class:`TimeStampF1D`

  """

  def __init__(self) -> None:

    """

    Builds a TimeStampF1D object.

    """

    ...

  def __call__(self, inter: freestyle.types.Interface1D) -> None:

    """

    Returns the time stamp of the Interface1D.

    """

    ...

class VertexOrientation2DF0D:

  """

  Class hierarchy: :class:`freestyle.types.UnaryFunction0D` > :class:`freestyle.types.UnaryFunction0DVec2f` > :class:`VertexOrientation2DF0D`

  """

  def __init__(self) -> None:

    """

    Builds a VertexOrientation2DF0D object.

    """

    ...

  def __call__(self, it: freestyle.types.Interface0DIterator) -> mathutils.Vector:

    """

    Returns a two-dimensional vector giving the 2D oriented tangent to the
1D element to which the :class:`freestyle.types.Interface0D` pointed
by the Interface0DIterator belongs.  The 2D oriented tangent is
evaluated at the pointed Interface0D.

    """

    ...

class VertexOrientation3DF0D:

  """

  Class hierarchy: :class:`freestyle.types.UnaryFunction0D` > :class:`freestyle.types.UnaryFunction0DVec3f` > :class:`VertexOrientation3DF0D`

  """

  def __init__(self) -> None:

    """

    Builds a VertexOrientation3DF0D object.

    """

    ...

  def __call__(self, it: freestyle.types.Interface0DIterator) -> mathutils.Vector:

    """

    Returns a three-dimensional vector giving the 3D oriented tangent to
the 1D element to which the :class:`freestyle.types.Interface0D`
pointed by the Interface0DIterator belongs.  The 3D oriented tangent
is evaluated at the pointed Interface0D.

    """

    ...

class ZDiscontinuityF0D:

  """

  Class hierarchy: :class:`freestyle.types.UnaryFunction0D` > :class:`freestyle.types.UnaryFunction0DDouble` > :class:`ZDiscontinuityF0D`

  """

  def __init__(self) -> None:

    """

    Builds a ZDiscontinuityF0D object.

    """

    ...

  def __call__(self, it: freestyle.types.Interface0DIterator) -> float:

    """

    Returns a real value giving the distance between the
:class:`freestyle.types.Interface0D` pointed by the
Interface0DIterator and the shape that lies behind (occludee).  This
distance is evaluated in the camera space and normalized between 0 and
1.  Therefore, if no object is occluded by the shape to which the
Interface0D belongs to, 1 is returned.

    """

    ...

class ZDiscontinuityF1D:

  """

  Class hierarchy: :class:`freestyle.types.UnaryFunction1D` > :class:`freestyle.types.UnaryFunction1DDouble` > :class:`ZDiscontinuityF1D`

  """

  def __init__(self, integration_type: freestyle.types.IntegrationType = IntegrationType.MEAN) -> None:

    """

    Builds a ZDiscontinuityF1D object.

    """

    ...

  def __call__(self, inter: freestyle.types.Interface1D) -> float:

    """

    Returns a real value giving the distance between an Interface1D
and the shape that lies behind (occludee).  This distance is
evaluated in the camera space and normalized between 0 and 1.
Therefore, if no object is occluded by the shape to which the
Interface1D belongs to, 1 is returned.

    """

    ...

class pyCurvilinearLengthF0D:

  ...

class pyDensityAnisotropyF0D:

  """

  Estimates the anisotropy of density.

  """

  ...

class pyDensityAnisotropyF1D:

  ...

class pyGetInverseProjectedZF1D:

  ...

class pyGetSquareInverseProjectedZF1D:

  ...

class pyInverseCurvature2DAngleF0D:

  ...

class pyViewMapGradientNormF0D:

  ...

class pyViewMapGradientNormF1D:

  ...

class pyViewMapGradientVectorF0D:

  """

  Returns the gradient vector for a pixel.

  """

  def __init__(self, level: int) -> None:

    """

    Builds a pyViewMapGradientVectorF0D object.

    """

    ...



"""


Cloth Operators
***************

:func:`preset_add`

"""

import typing

def preset_add(name: str = '', remove_name: bool = False, remove_active: bool = False) -> None:

  """

  Add or remove a Cloth Preset

  :file:`startup/bl_operators/presets.py\:73 <https://projects.blender.org/blender/blender/src/branch/main/scripts/startup/bl_operators/presets.py#L73>`_

  """

  ...



"""


Space Action Mode Items
^^^^^^^^^^^^^^^^^^^^^^^

:DOPESHEET:       
  Dope Sheet.

  Edit all keyframes in scene.

:TIMELINE:        
  Timeline.

  Timeline and playback controls.

.. _rna-enum-space-action-mode-items:

"""

import typing



"""


Brush Automasking Flag Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:use_automasking_topology:
  Topology.

  Affect only vertices connected to the active vertex under the brush.

:use_automasking_face_sets:
  Face Sets.

  Affect only vertices that share Face Sets with the active vertex.

:use_automasking_boundary_edges:
  Mesh Boundary Auto-Masking.

  Do not affect non manifold boundary edges.

:use_automasking_boundary_face_sets:
  Face Sets Boundary Automasking.

  Do not affect vertices that belong to a Face Set boundary.

:use_automasking_cavity:
  Cavity Mask.

  Do not affect vertices on peaks, based on the surface curvature.

:use_automasking_cavity_inverted:
  Inverted Cavity Mask.

  Do not affect vertices within crevices, based on the surface curvature.

:use_automasking_custom_cavity_curve:
  Custom Cavity Curve.

  Use custom curve.

.. _rna-enum-brush-automasking-flag-items:

"""

import typing



"""


Additional Math Functions (bl_math)
***********************************

Miscellaneous math utilities module

:func:`clamp`

:func:`lerp`

:func:`smoothstep`

"""

import typing

def clamp(value: float, min: float = 0, max: float = 1) -> float:

  """

  Clamps the float value between minimum and maximum. To avoid
confusion, any call must use either one or all three arguments.

  """

  ...

def lerp(from_value: float, to_value: float, factor: float) -> float:

  """

  Linearly interpolate between two float values based on factor.

  """

  ...

def smoothstep(from_value: float, to_value: float, value: typing.Any) -> float:

  """

  Performs smooth interpolation between 0 and 1 as value changes between from and to values.
Outside the range the function returns the same value as the nearest edge.

  """

  ...



"""


Ptcache Operators
*****************

:func:`add`

:func:`bake`

:func:`bake_all`

:func:`bake_from_cache`

:func:`free_bake`

:func:`free_bake_all`

:func:`remove`

"""

import typing

def add() -> None:

  """

  Add new cache

  """

  ...

def bake(bake: bool = False) -> None:

  """

  Bake physics

  """

  ...

def bake_all(bake: bool = True) -> None:

  """

  Bake all physics

  """

  ...

def bake_from_cache() -> None:

  """

  Bake from cache

  """

  ...

def free_bake() -> None:

  """

  Delete physics bake

  """

  ...

def free_bake_all() -> None:

  """

  Delete all baked caches of all objects in the current scene

  """

  ...

def remove() -> None:

  """

  Delete current cache

  """

  ...



"""


Keyframe Paste Offset Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^

:START:           
  Frame Start.

  Paste keys starting at current frame.

:END:             
  Frame End.

  Paste keys ending at current frame.

:RELATIVE:        
  Frame Relative.

  Paste keys relative to the current frame when copying.

:NONE:            
  No Offset.

  Paste keys from original time.

.. _rna-enum-keyframe-paste-offset-items:

"""

import typing



"""


Asset Operators
***************

:func:`bundle_install`

:func:`catalog_delete`

:func:`catalog_new`

:func:`catalog_redo`

:func:`catalog_undo`

:func:`catalog_undo_push`

:func:`catalogs_save`

:func:`clear`

:func:`library_refresh`

:func:`mark`

:func:`open_containing_blend_file`

:func:`tag_add`

:func:`tag_remove`

"""

import typing

def bundle_install(asset_library_ref: str = '', filepath: str = '', hide_props_region: bool = True, check_existing: bool = True, filter_blender: bool = True, filter_backup: bool = False, filter_image: bool = False, filter_movie: bool = False, filter_python: bool = False, filter_font: bool = False, filter_sound: bool = False, filter_text: bool = False, filter_archive: bool = False, filter_btx: bool = False, filter_collada: bool = False, filter_alembic: bool = False, filter_usd: bool = False, filter_obj: bool = False, filter_volume: bool = False, filter_folder: bool = True, filter_blenlib: bool = False, filemode: int = 8, display_type: str = 'DEFAULT', sort_method: str = '') -> None:

  """

  Copy the current .blend file into an Asset Library. Only works on standalone .blend files (i.e. when no other files are referenced)

  """

  ...

def catalog_delete(catalog_id: str = '') -> None:

  """

  Remove an asset catalog from the asset library (contained assets will not be affected and show up as unassigned)

  """

  ...

def catalog_new(parent_path: str = '') -> None:

  """

  Create a new catalog to put assets in

  """

  ...

def catalog_redo() -> None:

  """

  Redo the last undone edit to the asset catalogs

  """

  ...

def catalog_undo() -> None:

  """

  Undo the last edit to the asset catalogs

  """

  ...

def catalog_undo_push() -> None:

  """

  Store the current state of the asset catalogs in the undo buffer

  """

  ...

def catalogs_save() -> None:

  """

  Make any edits to any catalogs permanent by writing the current set up to the asset library

  """

  ...

def clear(set_fake_user: bool = False) -> None:

  """

  Delete all asset metadata and turn the selected asset data-blocks back into normal data-blocks

  """

  ...

def library_refresh() -> None:

  """

  Reread assets and asset catalogs from the asset library on disk

  """

  ...

def mark() -> None:

  """

  Enable easier reuse of selected data-blocks through the Asset Browser, with the help of customizable metadata (like previews, descriptions and tags)

  """

  ...

def open_containing_blend_file() -> None:

  """

  Open the blend file that contains the active asset

  :file:`startup/bl_operators/assets.py\:98 <https://projects.blender.org/blender/blender/src/branch/main/scripts/startup/bl_operators/assets.py#L98>`_

  """

  ...

def tag_add() -> None:

  """

  Add a new keyword tag to the active asset

  :file:`startup/bl_operators/assets.py\:39 <https://projects.blender.org/blender/blender/src/branch/main/scripts/startup/bl_operators/assets.py#L39>`_

  """

  ...

def tag_remove() -> None:

  """

  Remove an existing keyword tag from the active asset

  :file:`startup/bl_operators/assets.py\:62 <https://projects.blender.org/blender/blender/src/branch/main/scripts/startup/bl_operators/assets.py#L62>`_

  """

  ...



"""


Property Override Flag Collection Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:LIBRARY_OVERRIDABLE:
  Library Overridable.

  Make that property editable in library overrides of linked data-blocks.

:NO_PROPERTY_NAME:
  No Name.

  Do not use the names of the items, only their indices in the collection.

:USE_INSERTION:   
  Use Insertion.

  Allow users to add new items in that collection in library overrides.

.. _rna-enum-property-override-flag-collection-items:

"""

import typing



"""


Stereo3D Interlace Type Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:ROW_INTERLEAVED: 
  Row Interleaved.

:COLUMN_INTERLEAVED:
  Column Interleaved.

:CHECKERBOARD_INTERLEAVED:
  Checkerboard Interleaved.

.. _rna-enum-stereo3d-interlace-type-items:

"""

import typing



"""


Path Utilities (bpy.path)
*************************

This module has a similar scope to os.path, containing utility
functions for dealing with paths in Blender.

:func:`abspath`

:func:`basename`

:func:`clean_name`

:func:`display_name`

:func:`display_name_to_filepath`

:func:`display_name_from_filepath`

:func:`ensure_ext`

:func:`is_subdir`

:func:`module_names`

:func:`native_pathsep`

:func:`reduce_dirs`

:func:`relpath`

:func:`resolve_ncase`

"""

import typing

import bpy

def abspath(path: typing.Any, *args, start: str = None, library: bpy.types.Library = None) -> str:

  """

  Returns the absolute path relative to the current blend file
using the "//" prefix.

  """

  ...

def basename(path: typing.Any) -> None:

  """

  Equivalent to ``os.path.basename``, but skips a "//" prefix.

  Use for Windows compatibility.
:return: The base name of the given path.
:rtype: string

  """

  ...

def clean_name(name: typing.Any, *args, replace: typing.Any = '_') -> None:

  """

  Returns a name with characters replaced that
may cause problems under various circumstances,
such as writing to a file.
All characters besides A-Z/a-z, 0-9 are replaced with "_"
or the *replace* argument if defined.
:arg name: The path name.
:type name: string or bytes
:arg replace: The replacement for non-valid characters.
:type replace: string
:return: The cleaned name.
:rtype: string

  """

  ...

def display_name(name: str, *args, has_ext: bool = True, title_case: bool = True) -> str:

  """

  Creates a display string from name to be used menus and the user interface.
Intended for use with filenames and module names.

  """

  ...

def display_name_to_filepath(name: typing.Any) -> None:

  """

  Performs the reverse of display_name using literal versions of characters
which aren't supported in a filepath.
:arg name: The display name to convert.
:type name: string
:return: The file path.
:rtype: string

  """

  ...

def display_name_from_filepath(name: typing.Any) -> None:

  """

  Returns the path stripped of directory and extension,
ensured to be utf8 compatible.
:arg name: The file path to convert.
:type name: string
:return: The display name.
:rtype: string

  """

  ...

def ensure_ext(filepath: str, ext: str, *args, case_sensitive: bool = False) -> str:

  """

  Return the path with the extension added if it is not already set.

  """

  ...

def is_subdir(path: str, directory: typing.Any) -> bool:

  """

  Returns true if *path* in a subdirectory of *directory*.
Both paths must be absolute.

  """

  ...

def module_names(path: str, *args, recursive: bool = False) -> typing.List[str]:

  """

  Return a list of modules which can be imported from *path*.

  """

  ...

def native_pathsep(path: typing.Any) -> None:

  """

  Replace the path separator with the systems native ``os.sep``.
:arg path: The path to replace.
:type path: string
:return: The path with system native separators.
:rtype: string

  """

  ...

def reduce_dirs(dirs: typing.Sequence[str]) -> typing.List[str]:

  """

  Given a sequence of directories, remove duplicates and
any directories nested in one of the other paths.
(Useful for recursive path searching).

  """

  ...

def relpath(path: str, *args, start: str = None) -> str:

  """

  Returns the path relative to the current blend file using the "//" prefix.

  """

  ...

def resolve_ncase(path: typing.Any) -> None:

  """

  Resolve a case insensitive path on a case sensitive system,
returning a string with the path if found else return the original path.
:arg path: The path name to resolve.
:type path: string
:return: The resolved path.
:rtype: string

  """

  ...



"""


Fcurve Auto Smoothing Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^

:NONE:            
  None.

  Automatic handles only take immediately adjacent keys into account.

:CONT_ACCEL:      
  Continuous Acceleration.

  Automatic handles are adjusted to avoid jumps in acceleration, resulting in smoother curves. However, key changes may affect interpolation over a larger stretch of the curve.

.. _rna-enum-fcurve-auto-smoothing-items:

"""

import typing



"""


Property Type Items
^^^^^^^^^^^^^^^^^^^

:BOOLEAN:         
  Boolean.

:INT:             
  Integer.

:FLOAT:           
  Float.

:STRING:          
  String.

:ENUM:            
  Enumeration.

:POINTER:         
  Pointer.

:COLLECTION:      
  Collection.

.. _rna-enum-property-type-items:

"""

import typing



"""


Fluid Operators
***************

:func:`bake_all`

:func:`bake_data`

:func:`bake_guides`

:func:`bake_mesh`

:func:`bake_noise`

:func:`bake_particles`

:func:`free_all`

:func:`free_data`

:func:`free_guides`

:func:`free_mesh`

:func:`free_noise`

:func:`free_particles`

:func:`pause_bake`

:func:`preset_add`

"""

import typing

def bake_all() -> None:

  """

  Bake Entire Fluid Simulation

  """

  ...

def bake_data() -> None:

  """

  Bake Fluid Data

  """

  ...

def bake_guides() -> None:

  """

  Bake Fluid Guiding

  """

  ...

def bake_mesh() -> None:

  """

  Bake Fluid Mesh

  """

  ...

def bake_noise() -> None:

  """

  Bake Fluid Noise

  """

  ...

def bake_particles() -> None:

  """

  Bake Fluid Particles

  """

  ...

def free_all() -> None:

  """

  Free Entire Fluid Simulation

  """

  ...

def free_data() -> None:

  """

  Free Fluid Data

  """

  ...

def free_guides() -> None:

  """

  Free Fluid Guiding

  """

  ...

def free_mesh() -> None:

  """

  Free Fluid Mesh

  """

  ...

def free_noise() -> None:

  """

  Free Fluid Noise

  """

  ...

def free_particles() -> None:

  """

  Free Fluid Particles

  """

  ...

def pause_bake() -> None:

  """

  Pause Bake

  """

  ...

def preset_add(name: str = '', remove_name: bool = False, remove_active: bool = False) -> None:

  """

  Add or remove a Fluid Preset

  :file:`startup/bl_operators/presets.py\:73 <https://projects.blender.org/blender/blender/src/branch/main/scripts/startup/bl_operators/presets.py#L73>`_

  """

  ...



"""


Node Vec Math Items
^^^^^^^^^^^^^^^^^^^

:ADD:             
  Add.

  A + B.

:SUBTRACT:        
  Subtract.

  A - B.

:MULTIPLY:        
  Multiply.

  Entry-wise multiply.

:DIVIDE:          
  Divide.

  Entry-wise divide.

:MULTIPLY_ADD:    
  Multiply Add.

  A * B + C.

.. _rna-enum-node-vec-math-items:

======================================================================

:CROSS_PRODUCT:   
  Cross Product.

  A cross B.

:PROJECT:         
  Project.

  Project A onto B.

:REFLECT:         
  Reflect.

  Reflect A around the normal B. B doesn't need to be normalized.

:REFRACT:         
  Refract.

  For a given incident vector A, surface normal B and ratio of indices of refraction, Ior, refract returns the refraction vector, R.

:FACEFORWARD:     
  Faceforward.

  Orients a vector A to point away from a surface B as defined by its normal C. Returns (dot(B, C) < 0) ? A : -A.

:DOT_PRODUCT:     
  Dot Product.

  A dot B.

======================================================================

:DISTANCE:        
  Distance.

  Distance between A and B.

:LENGTH:          
  Length.

  Length of A.

:SCALE:           
  Scale.

  A multiplied by Scale.

:NORMALIZE:       
  Normalize.

  Normalize A.

======================================================================

:ABSOLUTE:        
  Absolute.

  Entry-wise absolute.

:MINIMUM:         
  Minimum.

  Entry-wise minimum.

:MAXIMUM:         
  Maximum.

  Entry-wise maximum.

:FLOOR:           
  Floor.

  Entry-wise floor.

:CEIL:            
  Ceil.

  Entry-wise ceil.

:FRACTION:        
  Fraction.

  The fraction part of A entry-wise.

:MODULO:          
  Modulo.

  Entry-wise modulo using fmod(A,B).

:WRAP:            
  Wrap.

  Entry-wise wrap(A,B).

:SNAP:            
  Snap.

  Round A to the largest integer multiple of B less than or equal A.

======================================================================

:SINE:            
  Sine.

  Entry-wise sin(A).

:COSINE:          
  Cosine.

  Entry-wise cos(A).

:TANGENT:         
  Tangent.

  Entry-wise tan(A).

"""

import typing



"""


Event Direction Items
^^^^^^^^^^^^^^^^^^^^^

:ANY:             
  Any.

:NORTH:           
  North.

:NORTH_EAST:      
  North-East.

:EAST:            
  East.

:SOUTH_EAST:      
  South-East.

:SOUTH:           
  South.

:SOUTH_WEST:      
  South-West.

:WEST:            
  West.

:NORTH_WEST:      
  North-West.

.. _rna-enum-event-direction-items:

"""

import typing



"""


Symmetrize Direction Items
^^^^^^^^^^^^^^^^^^^^^^^^^^

:NEGATIVE_X:      
  -X to +X.

:POSITIVE_X:      
  +X to -X.

:NEGATIVE_Y:      
  -Y to +Y.

:POSITIVE_Y:      
  +Y to -Y.

:NEGATIVE_Z:      
  -Z to +Z.

:POSITIVE_Z:      
  +Z to -Z.

.. _rna-enum-symmetrize-direction-items:

"""

import typing



"""


Space Image Mode Items
^^^^^^^^^^^^^^^^^^^^^^

:IMAGE_EDITOR:    
  Image Editor.

  View the image.

:UV:              
  UV Editor.

  UV edit in mesh editmode.

.. _rna-enum-space-image-mode-items:

"""

import typing



"""


Image Buffer Types (imbuf.types)
********************************

This module provides access to image buffer types.

Note: Image buffer is also the structure used by :class:`bpy.types.Image`
ID type to store and manipulate image data at runtime.

:class:`ImBuf`

"""

import typing

class ImBuf:

  def copy(self) -> ImBuf:

    ...

  def crop(self, min: typing.Tuple[int, int], max: typing.Tuple[int, int]) -> None:

    """

    Crop the image.

    """

    ...

  def free(self) -> None:

    """

    Clear image data immediately (causing an error on re-use).

    """

    ...

  def resize(self, size: typing.Tuple[int, int], method: str = 'FAST') -> None:

    """

    Resize the image.

    """

    ...

  channels: int = ...

  """

  Number of bit-planes.

  """

  filepath: str = ...

  """

  filepath associated with this image.

  """

  planes: int = ...

  """

  Number of bits associated with this image.

  """

  ppm: typing.Tuple[float, float] = ...

  """

  pixels per meter.

  """

  size: typing.Tuple[int, int] = ...

  """

  size of the image in pixels.

  """



"""


Texture Type Items
^^^^^^^^^^^^^^^^^^

:NONE:            
  None.

:BLEND:           
  Blend.

  Procedural - create a ramp texture.

:CLOUDS:          
  Clouds.

  Procedural - create a cloud-like fractal noise texture.

:DISTORTED_NOISE: 
  Distorted Noise.

  Procedural - noise texture distorted by two noise algorithms.

:IMAGE:           
  Image or Movie.

  Allow for images or movies to be used as textures.

:MAGIC:           
  Magic.

  Procedural - color texture based on trigonometric functions.

:MARBLE:          
  Marble.

  Procedural - marble-like noise texture with wave generated bands.

:MUSGRAVE:        
  Musgrave.

  Procedural - highly flexible fractal noise texture.

:NOISE:           
  Noise.

  Procedural - random noise, gives a different result every time, for every frame, for every pixel.

:STUCCI:          
  Stucci.

  Procedural - create a fractal noise texture.

:VORONOI:         
  Voronoi.

  Procedural - create cell-like patterns based on Worley noise.

:WOOD:            
  Wood.

  Procedural - wave generated bands or rings, with optional noise.

.. _rna-enum-texture-type-items:

"""

import typing



"""


Constraint Type Items
^^^^^^^^^^^^^^^^^^^^^

.. _rna-enum-constraint-type-items:

**Motion Tracking**

:CAMERA_SOLVER:   
  Camera Solver.

:FOLLOW_TRACK:    
  Follow Track.

:OBJECT_SOLVER:   
  Object Solver.

**Transform**

:COPY_LOCATION:   
  Copy Location.

  Copy the location of a target (with an optional offset), so that they move together.

:COPY_ROTATION:   
  Copy Rotation.

  Copy the rotation of a target (with an optional offset), so that they rotate together.

:COPY_SCALE:      
  Copy Scale.

  Copy the scale factors of a target (with an optional offset), so that they are scaled by the same amount.

:COPY_TRANSFORMS: 
  Copy Transforms.

  Copy all the transformations of a target, so that they move together.

:LIMIT_DISTANCE:  
  Limit Distance.

  Restrict movements to within a certain distance of a target (at the time of constraint evaluation only).

:LIMIT_LOCATION:  
  Limit Location.

  Restrict movement along each axis within given ranges.

:LIMIT_ROTATION:  
  Limit Rotation.

  Restrict rotation along each axis within given ranges.

:LIMIT_SCALE:     
  Limit Scale.

  Restrict scaling along each axis with given ranges.

:MAINTAIN_VOLUME: 
  Maintain Volume.

  Compensate for scaling one axis by applying suitable scaling to the other two axes.

:TRANSFORM:       
  Transformation.

  Use one transform property from target to control another (or same) property on owner.

:TRANSFORM_CACHE: 
  Transform Cache.

  Look up the transformation matrix from an external file.

**Tracking**

:CLAMP_TO:        
  Clamp To.

  Restrict movements to lie along a curve by remapping location along curve's longest axis.

:DAMPED_TRACK:    
  Damped Track.

  Point towards a target by performing the smallest rotation necessary.

:IK:              
  Inverse Kinematics.

  Control a chain of bones by specifying the endpoint target (Bones only).

:LOCKED_TRACK:    
  Locked Track.

  Rotate around the specified ('locked') axis to point towards a target.

:SPLINE_IK:       
  Spline IK.

  Align chain of bones along a curve (Bones only).

:STRETCH_TO:      
  Stretch To.

  Stretch along Y-Axis to point towards a target.

:TRACK_TO:        
  Track To.

  Legacy tracking constraint prone to twisting artifacts.

**Relationship**

:ACTION:          
  Action.

  Use transform property of target to look up pose for owner from an Action.

:ARMATURE:        
  Armature.

  Apply weight-blended transformation from multiple bones like the Armature modifier.

:CHILD_OF:        
  Child Of.

  Make target the 'detachable' parent of owner.

:FLOOR:           
  Floor.

  Use position (and optionally rotation) of target to define a 'wall' or 'floor' that the owner can not cross.

:FOLLOW_PATH:     
  Follow Path.

  Use to animate an object/bone following a path.

:PIVOT:           
  Pivot.

  Change pivot point for transforms (buggy).

:SHRINKWRAP:      
  Shrinkwrap.

  Restrict movements to surface of target mesh.

"""

import typing



"""


Brush Gpencil Weight Types Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:WEIGHT:          
  Weight.

  Weight Paint for Vertex Groups.

.. _rna-enum-brush-gpencil-weight-types-items:

"""

import typing



"""


Operators (bpy.ops)
*******************


Calling Operators
=================

Provides python access to calling operators, this includes operators written in
C, Python or macros.

Only keyword arguments can be used to pass operator properties.

Operators don't have return values as you might expect,
instead they return a set() which is made up of:
``{'RUNNING_MODAL', 'CANCELLED', 'FINISHED', 'PASS_THROUGH'}``.
Common return values are ``{'FINISHED'}`` and ``{'CANCELLED'}``, the latter
meaning that the operator execution was aborted without making any changes or
saving an undo history entry.

Calling an operator in the wrong context will raise a ``RuntimeError``,
there is a poll() method to avoid this problem.

Note that the operator ID (bl_idname) in this example is ``mesh.subdivide``,
``bpy.ops`` is just the access path for python.


Keywords and Positional Arguments
---------------------------------

For calling operators keywords are used for operator properties and
positional arguments are used to define how the operator is called.

There are 3 optional positional arguments (documented in detail below).

.. code:: python

  bpy.ops.test.operator(override_context, execution_context, undo)

* override_context - ``dict`` type.

  Deprecated since version 3.2: :class:`bpy.types.Context.temp_override` should be used instead of this argument.

* execution_context - ``str`` (enum).

* undo - ``bool`` type.

Each of these arguments is optional, but must be given in the order above.

.. code::

  import bpy

  # calling an operator
  bpy.ops.mesh.subdivide(number_cuts=3, smoothness=0.5)


  # check poll() to avoid exception.
  if bpy.ops.object.mode_set.poll():
      bpy.ops.object.mode_set(mode='EDIT')


Overriding Context
==================

It is possible to override context members that the operator sees, so that they
act on specified rather than the selected or active data, or to execute an
operator in the different part of the user interface.

The context overrides are passed as a dictionary, with keys matching the context
member names in bpy.context.
For example to override ``bpy.context.active_object``,
you would pass ``{'active_object': object}`` to :class:`bpy.types.Context.temp_override`.

Note: You will nearly always want to use a copy of the actual current context as basis
(otherwise, you'll have to find and gather all needed data yourself).

.. code::

  # Remove all objects in scene rather than the selected ones.
  import bpy
  from bpy import context
  override = context.copy()
  override["selected_objects"] = list(context.scene.objects)
  with context.temp_override(**override):
      bpy.ops.object.delete()

.. _operator-execution-context:


Execution Context
=================

When calling an operator you may want to pass the execution context.

This determines the context that is given for the operator to run in, and whether
invoke() is called or only execute().

``EXEC_DEFAULT`` is used by default, running only the ``execute()`` method, but you may
want the operator to take user interaction with ``INVOKE_DEFAULT`` which will also
call invoke() if existing.

The execution context is one of:

* ``INVOKE_DEFAULT``

* ``INVOKE_REGION_WIN``

* ``INVOKE_REGION_CHANNELS``

* ``INVOKE_REGION_PREVIEW``

* ``INVOKE_AREA``

* ``INVOKE_SCREEN``

* ``EXEC_DEFAULT``

* ``EXEC_REGION_WIN``

* ``EXEC_REGION_CHANNELS``

* ``EXEC_REGION_PREVIEW``

* ``EXEC_AREA``

* ``EXEC_SCREEN``

.. code::

  # collection add popup
  import bpy
  bpy.ops.object.collection_instance_add('INVOKE_DEFAULT')

It is also possible to run an operator in a particular part of the user
interface. For this we need to pass the window, area and sometimes a region.

.. code::

  # Maximize 3d view in all windows.
  import bpy
  from bpy import context

  for window in context.window_manager.windows:
      screen = window.screen
      for area in screen.areas:
          if area.type == 'VIEW_3D':
              with context.temp_override(window=window, area=area):
                  bpy.ops.screen.screen_full_area()
              break

"""

from . import world

from . import workspace

from . import wm

from . import view3d

from . import view2d

from . import uv

from . import uilist

from . import ui

from . import transform

from . import texture

from . import text

from . import surface

from . import spreadsheet

from . import sound

from . import sequencer

from . import sculpt_curves

from . import sculpt

from . import script

from . import screen

from . import scene

from . import rigidbody

from . import render

from . import ptcache

from . import preferences

from . import poselib

from . import pose

from . import particle

from . import palette

from . import paintcurve

from . import paint

from . import outliner

from . import object

from . import node

from . import nla

from . import mesh

from . import mball

from . import material

from . import mask

from . import marker

from . import lattice

from . import info

from . import image

from . import graph

from . import gpencil

from . import gizmogroup

from . import geometry

from . import font

from . import fluid

from . import file

from . import ed

from . import dpaint

from . import curves

from . import curve

from . import constraint

from . import console

from . import collection

from . import cloth

from . import clip

from . import camera

from . import cachefile

from . import buttons

from . import brush

from . import boid

from . import asset

from . import armature

from . import anim

from . import action

import typing



"""


Space Type Items
^^^^^^^^^^^^^^^^

:EMPTY:           
  Empty.

.. _rna-enum-space-type-items:

**General**

:VIEW_3D:         
  3D Viewport.

  Manipulate objects in a 3D environment.

:IMAGE_EDITOR:    
  UV/Image Editor.

  View and edit images and UV Maps.

:NODE_EDITOR:     
  Node Editor.

  Editor for node-based shading and compositing tools.

:SEQUENCE_EDITOR: 
  Video Sequencer.

  Video editing tools.

:CLIP_EDITOR:     
  Movie Clip Editor.

  Motion tracking tools.

**Animation**

:DOPESHEET_EDITOR:
  Dope Sheet.

  Adjust timing of keyframes.

:GRAPH_EDITOR:    
  Graph Editor.

  Edit drivers and keyframe interpolation.

:NLA_EDITOR:      
  Nonlinear Animation.

  Combine and layer Actions.

**Scripting**

:TEXT_EDITOR:     
  Text Editor.

  Edit scripts and in-file documentation.

:CONSOLE:         
  Python Console.

  Interactive programmatic console for advanced editing and script development.

:INFO:            
  Info.

  Log of operations, warnings and error messages.

:TOPBAR:          
  Top Bar.

  Global bar at the top of the screen for global per-window settings.

:STATUSBAR:       
  Status Bar.

  Global bar at the bottom of the screen for general status information.

**Data**

:OUTLINER:        
  Outliner.

  Overview of scene graph and all available data-blocks.

:PROPERTIES:      
  Properties.

  Edit properties of active object and related data-blocks.

:FILE_BROWSER:    
  File Browser.

  Browse for files and assets.

:SPREADSHEET:     
  Spreadsheet.

  Explore geometry data in a table.

:PREFERENCES:     
  Preferences.

  Edit persistent configuration settings.

"""

import typing



"""


Geometry Operators
******************

:func:`attribute_add`

:func:`attribute_convert`

:func:`attribute_remove`

:func:`color_attribute_add`

:func:`color_attribute_convert`

:func:`color_attribute_duplicate`

:func:`color_attribute_remove`

:func:`color_attribute_render_set`

"""

import typing

def attribute_add(name: str = 'Attribute', domain: str = 'POINT', data_type: str = 'FLOAT') -> None:

  """

  Add attribute to geometry

  """

  ...

def attribute_convert(mode: str = 'GENERIC', domain: str = 'POINT', data_type: str = 'FLOAT') -> None:

  """

  Change how the attribute is stored

  """

  ...

def attribute_remove() -> None:

  """

  Remove attribute from geometry

  """

  ...

def color_attribute_add(name: str = 'Color', domain: str = 'POINT', data_type: str = 'FLOAT_COLOR', color: typing.Tuple[float, float, float, float] = (0.0, 0.0, 0.0, 1.0)) -> None:

  """

  Add color attribute to geometry

  """

  ...

def color_attribute_convert(domain: str = 'POINT', data_type: str = 'FLOAT_COLOR') -> None:

  """

  Change how the color attribute is stored

  """

  ...

def color_attribute_duplicate() -> None:

  """

  Duplicate color attribute

  """

  ...

def color_attribute_remove() -> None:

  """

  Remove color attribute from geometry

  """

  ...

def color_attribute_render_set(name: str = 'Color') -> None:

  """

  Set default color attribute used for rendering

  """

  ...



"""


Stereo3D Anaglyph Type Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:RED_CYAN:        
  Red-Cyan.

:GREEN_MAGENTA:   
  Green-Magenta.

:YELLOW_BLUE:     
  Yellow-Blue.

.. _rna-enum-stereo3d-anaglyph-type-items:

"""

import typing



"""


Object Type Curve Items
^^^^^^^^^^^^^^^^^^^^^^^

:CURVE:           
  Curve.

:SURFACE:         
  Surface.

:FONT:            
  Text.

.. _rna-enum-object-type-curve-items:

"""

import typing



"""


Property Subtype String Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:FILE_PATH:       
  File Path.

:DIR_PATH:        
  Directory Path.

:FILE_NAME:       
  File Name.

:BYTE_STRING:     
  Byte String.

:PASSWORD:        
  Password.

  A string that is displayed hidden ('********').

:NONE:            
  None.

.. _rna-enum-property-subtype-string-items:

"""

import typing



"""


Nla Operators
*************

:func:`action_pushdown`

:func:`action_sync_length`

:func:`action_unlink`

:func:`actionclip_add`

:func:`apply_scale`

:func:`bake`

:func:`channels_click`

:func:`clear_scale`

:func:`click_select`

:func:`delete`

:func:`duplicate`

:func:`duplicate_linked_move`

:func:`duplicate_move`

:func:`fmodifier_add`

:func:`fmodifier_copy`

:func:`fmodifier_paste`

:func:`make_single_user`

:func:`meta_add`

:func:`meta_remove`

:func:`move_down`

:func:`move_up`

:func:`mute_toggle`

:func:`previewrange_set`

:func:`select_all`

:func:`select_box`

:func:`select_leftright`

:func:`selected_objects_add`

:func:`snap`

:func:`soundclip_add`

:func:`split`

:func:`swap`

:func:`tracks_add`

:func:`tracks_delete`

:func:`transition_add`

:func:`tweakmode_enter`

:func:`tweakmode_exit`

:func:`view_all`

:func:`view_frame`

:func:`view_selected`

"""

import typing

def action_pushdown(channel_index: int = -1) -> None:

  """

  Push action down onto the top of the NLA stack as a new strip

  """

  ...

def action_sync_length(active: bool = True) -> None:

  """

  Synchronize the length of the referenced Action with the length used in the strip

  """

  ...

def action_unlink(force_delete: bool = False) -> None:

  """

  Unlink this action from the active action slot (and/or exit Tweak Mode)

  """

  ...

def actionclip_add(action: str = '') -> None:

  """

  Add an Action-Clip strip (i.e. an NLA Strip referencing an Action) to the active track

  """

  ...

def apply_scale() -> None:

  """

  Apply scaling of selected strips to their referenced Actions

  """

  ...

def bake(frame_start: int = 1, frame_end: int = 250, step: int = 1, only_selected: bool = True, visual_keying: bool = False, clear_constraints: bool = False, clear_parents: bool = False, use_current_action: bool = False, clean_curves: bool = False, bake_types: typing.Set[str] = {'POSE'}) -> None:

  """

  Bake all selected objects location/scale/rotation animation to an action

  :file:`startup/bl_operators/anim.py\:253 <https://projects.blender.org/blender/blender/src/branch/main/scripts/startup/bl_operators/anim.py#L253>`_

  """

  ...

def channels_click(extend: bool = False) -> None:

  """

  Handle clicks to select NLA channels

  """

  ...

def clear_scale() -> None:

  """

  Reset scaling of selected strips

  """

  ...

def click_select(wait_to_deselect_others: bool = False, mouse_x: int = 0, mouse_y: int = 0, extend: bool = False, deselect_all: bool = False) -> None:

  """

  Handle clicks to select NLA Strips

  """

  ...

def delete() -> None:

  """

  Delete selected strips

  """

  ...

def duplicate(linked: bool = False) -> None:

  """

  Duplicate selected NLA-Strips, adding the new strips in new tracks above the originals

  """

  ...

def duplicate_linked_move(NLA_OT_duplicate: NLA_OT_duplicate = None, TRANSFORM_OT_translate: TRANSFORM_OT_translate = None) -> None:

  """

  Duplicate selected strips and move them

  """

  ...

def duplicate_move(NLA_OT_duplicate: NLA_OT_duplicate = None, TRANSFORM_OT_translate: TRANSFORM_OT_translate = None) -> None:

  """

  Duplicate selected strips and their Actions and move them

  """

  ...

def fmodifier_add(type: str = 'NULL', only_active: bool = True) -> None:

  """

  Add F-Modifier to the active/selected NLA-Strips

  """

  ...

def fmodifier_copy() -> None:

  """

  Copy the F-Modifier(s) of the active NLA-Strip

  """

  ...

def fmodifier_paste(only_active: bool = True, replace: bool = False) -> None:

  """

  Add copied F-Modifiers to the selected NLA-Strips

  """

  ...

def make_single_user() -> None:

  """

  Ensure that each action is only used once in the set of strips selected

  """

  ...

def meta_add() -> None:

  """

  Add new meta-strips incorporating the selected strips

  """

  ...

def meta_remove() -> None:

  """

  Separate out the strips held by the selected meta-strips

  """

  ...

def move_down() -> None:

  """

  Move selected strips down a track if there's room

  """

  ...

def move_up() -> None:

  """

  Move selected strips up a track if there's room

  """

  ...

def mute_toggle() -> None:

  """

  Mute or un-mute selected strips

  """

  ...

def previewrange_set() -> None:

  """

  Set Preview Range based on extends of selected strips

  """

  ...

def select_all(action: str = 'TOGGLE') -> None:

  """

  Select or deselect all NLA-Strips

  """

  ...

def select_box(axis_range: bool = False, tweak: bool = False, xmin: int = 0, xmax: int = 0, ymin: int = 0, ymax: int = 0, wait_for_input: bool = True, mode: str = 'SET') -> None:

  """

  Use box selection to grab NLA-Strips

  """

  ...

def select_leftright(mode: str = 'CHECK', extend: bool = False) -> None:

  """

  Select strips to the left or the right of the current frame

  """

  ...

def selected_objects_add() -> None:

  """

  Make selected objects appear in NLA Editor by adding Animation Data

  """

  ...

def snap(type: str = 'CFRA') -> None:

  """

  Move start of strips to specified time

  """

  ...

def soundclip_add() -> None:

  """

  Add a strip for controlling when speaker plays its sound clip

  """

  ...

def split() -> None:

  """

  Split selected strips at their midpoints

  """

  ...

def swap() -> None:

  """

  Swap order of selected strips within tracks

  """

  ...

def tracks_add(above_selected: bool = False) -> None:

  """

  Add NLA-Tracks above/after the selected tracks

  """

  ...

def tracks_delete() -> None:

  """

  Delete selected NLA-Tracks and the strips they contain

  """

  ...

def transition_add() -> None:

  """

  Add a transition strip between two adjacent selected strips

  """

  ...

def tweakmode_enter(isolate_action: bool = False, use_upper_stack_evaluation: bool = False) -> None:

  """

  Enter tweaking mode for the action referenced by the active strip to edit its keyframes

  """

  ...

def tweakmode_exit(isolate_action: bool = False) -> None:

  """

  Exit tweaking mode for the action referenced by the active strip

  """

  ...

def view_all() -> None:

  """

  Reset viewable area to show full strips range

  """

  ...

def view_frame() -> None:

  """

  Move the view to the current frame

  """

  ...

def view_selected() -> None:

  """

  Reset viewable area to show selected strips range

  """

  ...



"""


Console Operators
*****************

:func:`autocomplete`

:func:`banner`

:func:`clear`

:func:`clear_line`

:func:`copy`

:func:`copy_as_script`

:func:`delete`

:func:`execute`

:func:`history_append`

:func:`history_cycle`

:func:`indent`

:func:`indent_or_autocomplete`

:func:`insert`

:func:`language`

:func:`move`

:func:`paste`

:func:`scrollback_append`

:func:`select_set`

:func:`select_word`

:func:`unindent`

"""

import typing

def autocomplete() -> None:

  """

  Evaluate the namespace up until the cursor and give a list of options or complete the name if there is only one

  :file:`startup/bl_operators/console.py\:56 <https://projects.blender.org/blender/blender/src/branch/main/scripts/startup/bl_operators/console.py#L56>`_

  """

  ...

def banner() -> None:

  """

  Print a message when the terminal initializes

  :file:`startup/bl_operators/console.py\:101 <https://projects.blender.org/blender/blender/src/branch/main/scripts/startup/bl_operators/console.py#L101>`_

  """

  ...

def clear(scrollback: bool = True, history: bool = False) -> None:

  """

  Clear text by type

  """

  ...

def clear_line() -> None:

  """

  Clear the line and store in history

  """

  ...

def copy() -> None:

  """

  Copy selected text to clipboard

  """

  ...

def copy_as_script() -> None:

  """

  Copy the console contents for use in a script

  :file:`startup/bl_operators/console.py\:78 <https://projects.blender.org/blender/blender/src/branch/main/scripts/startup/bl_operators/console.py#L78>`_

  """

  ...

def delete(type: str = 'NEXT_CHARACTER') -> None:

  """

  Delete text by cursor position

  """

  ...

def execute(interactive: bool = False) -> None:

  """

  Execute the current console line as a python expression

  :file:`startup/bl_operators/console.py\:32 <https://projects.blender.org/blender/blender/src/branch/main/scripts/startup/bl_operators/console.py#L32>`_

  """

  ...

def history_append(text: str = '', current_character: int = 0, remove_duplicates: bool = False) -> None:

  """

  Append history at cursor position

  """

  ...

def history_cycle(reverse: bool = False) -> None:

  """

  Cycle through history

  """

  ...

def indent() -> None:

  """

  Add 4 spaces at line beginning

  """

  ...

def indent_or_autocomplete() -> None:

  """

  Indent selected text or autocomplete

  """

  ...

def insert(text: str = '') -> None:

  """

  Insert text at cursor position

  """

  ...

def language(language: str = '') -> None:

  """

  Set the current language for this console

  :file:`startup/bl_operators/console.py\:133 <https://projects.blender.org/blender/blender/src/branch/main/scripts/startup/bl_operators/console.py#L133>`_

  """

  ...

def move(type: str = 'LINE_BEGIN') -> None:

  """

  Move cursor position

  """

  ...

def paste(selection: bool = False) -> None:

  """

  Paste text from clipboard

  """

  ...

def scrollback_append(text: str = '', type: str = 'OUTPUT') -> None:

  """

  Append scrollback text by type

  """

  ...

def select_set() -> None:

  """

  Set the console selection

  """

  ...

def select_word() -> None:

  """

  Select word at cursor position

  """

  ...

def unindent() -> None:

  """

  Delete 4 spaces from line beginning

  """

  ...



"""


Poselib Operators
*****************

:func:`apply_pose_asset`

:func:`blend_pose_asset`

"""

import typing

def apply_pose_asset(blend_factor: float = 1.0, flipped: bool = False) -> None:

  """

  Apply the given Pose Action to the rig

  """

  ...

def blend_pose_asset(blend_factor: float = 0.0, flipped: bool = False, release_confirm: bool = False) -> None:

  """

  Blend the given Pose Action to the rig

  """

  ...



"""


Constraint Operators
********************

:func:`add_target`

:func:`apply`

:func:`childof_clear_inverse`

:func:`childof_set_inverse`

:func:`copy`

:func:`copy_to_selected`

:func:`delete`

:func:`disable_keep_transform`

:func:`followpath_path_animate`

:func:`limitdistance_reset`

:func:`move_down`

:func:`move_to_index`

:func:`move_up`

:func:`normalize_target_weights`

:func:`objectsolver_clear_inverse`

:func:`objectsolver_set_inverse`

:func:`remove_target`

:func:`stretchto_reset`

"""

import typing

def add_target() -> None:

  """

  Add a target to the constraint

  :file:`startup/bl_operators/constraint.py\:23 <https://projects.blender.org/blender/blender/src/branch/main/scripts/startup/bl_operators/constraint.py#L23>`_

  """

  ...

def apply(constraint: str = '', owner: str = 'OBJECT', report: bool = False) -> None:

  """

  Apply constraint and remove from the stack

  """

  ...

def childof_clear_inverse(constraint: str = '', owner: str = 'OBJECT') -> None:

  """

  Clear inverse correction for Child Of constraint

  """

  ...

def childof_set_inverse(constraint: str = '', owner: str = 'OBJECT') -> None:

  """

  Set inverse correction for Child Of constraint

  """

  ...

def copy(constraint: str = '', owner: str = 'OBJECT', report: bool = False) -> None:

  """

  Duplicate constraint at the same position in the stack

  """

  ...

def copy_to_selected(constraint: str = '', owner: str = 'OBJECT') -> None:

  """

  Copy constraint to other selected objects/bones

  """

  ...

def delete(constraint: str = '', owner: str = 'OBJECT', report: bool = False) -> None:

  """

  Remove constraint from constraint stack

  """

  ...

def disable_keep_transform() -> None:

  """

  Set the influence of this constraint to zero while trying to maintain the object's transformation. Other active constraints can still influence the final transformation

  :file:`startup/bl_operators/constraint.py\:83 <https://projects.blender.org/blender/blender/src/branch/main/scripts/startup/bl_operators/constraint.py#L83>`_

  """

  ...

def followpath_path_animate(constraint: str = '', owner: str = 'OBJECT', frame_start: int = 1, length: int = 100) -> None:

  """

  Add default animation for path used by constraint if it isn't animated already

  """

  ...

def limitdistance_reset(constraint: str = '', owner: str = 'OBJECT') -> None:

  """

  Reset limiting distance for Limit Distance Constraint

  """

  ...

def move_down(constraint: str = '', owner: str = 'OBJECT') -> None:

  """

  Move constraint down in constraint stack

  """

  ...

def move_to_index(constraint: str = '', owner: str = 'OBJECT', index: int = 0) -> None:

  """

  Change the constraint's position in the list so it evaluates after the set number of others

  """

  ...

def move_up(constraint: str = '', owner: str = 'OBJECT') -> None:

  """

  Move constraint up in constraint stack

  """

  ...

def normalize_target_weights() -> None:

  """

  Normalize weights of all target bones

  :file:`startup/bl_operators/constraint.py\:58 <https://projects.blender.org/blender/blender/src/branch/main/scripts/startup/bl_operators/constraint.py#L58>`_

  """

  ...

def objectsolver_clear_inverse(constraint: str = '', owner: str = 'OBJECT') -> None:

  """

  Clear inverse correction for Object Solver constraint

  """

  ...

def objectsolver_set_inverse(constraint: str = '', owner: str = 'OBJECT') -> None:

  """

  Set inverse correction for Object Solver constraint

  """

  ...

def remove_target(index: int = 0) -> None:

  """

  Remove the target from the constraint

  :file:`startup/bl_operators/constraint.py\:41 <https://projects.blender.org/blender/blender/src/branch/main/scripts/startup/bl_operators/constraint.py#L41>`_

  """

  ...

def stretchto_reset(constraint: str = '', owner: str = 'OBJECT') -> None:

  """

  Reset original length of bone for Stretch To Constraint

  """

  ...



"""


GPU Matrix Utilities (gpu.matrix)
*********************************

This module provides access to the matrix stack.

:func:`get_model_view_matrix`

:func:`get_normal_matrix`

:func:`get_projection_matrix`

:func:`load_identity`

:func:`load_matrix`

:func:`load_projection_matrix`

:func:`multiply_matrix`

:func:`pop`

:func:`pop_projection`

:func:`push`

:func:`push_pop`

:func:`push_pop_projection`

:func:`push_projection`

:func:`reset`

:func:`scale`

:func:`scale_uniform`

:func:`translate`

"""

import typing

import mathutils

def get_model_view_matrix() -> mathutils.Matrix:

  """

  Return a copy of the model-view matrix.

  """

  ...

def get_normal_matrix() -> mathutils.Matrix:

  """

  Return a copy of the normal matrix.

  """

  ...

def get_projection_matrix() -> mathutils.Matrix:

  """

  Return a copy of the projection matrix.

  """

  ...

def load_identity() -> None:

  """

  Empty stack and set to identity.

  """

  ...

def load_matrix(matrix: mathutils.Matrix) -> None:

  """

  Load a matrix into the stack.

  """

  ...

def load_projection_matrix(matrix: mathutils.Matrix) -> None:

  """

  Load a projection matrix into the stack.

  """

  ...

def multiply_matrix(matrix: mathutils.Matrix) -> None:

  """

  Multiply the current stack matrix.

  """

  ...

def pop() -> None:

  """

  Remove the last model-view matrix from the stack.

  """

  ...

def pop_projection() -> None:

  """

  Remove the last projection matrix from the stack.

  """

  ...

def push() -> None:

  """

  Add to the model-view matrix stack.

  """

  ...

def push_pop() -> None:

  """

  Context manager to ensure balanced push/pop calls, even in the case of an error.

  """

  ...

def push_pop_projection() -> None:

  """

  Context manager to ensure balanced push/pop calls, even in the case of an error.

  """

  ...

def push_projection() -> None:

  """

  Add to the projection matrix stack.

  """

  ...

def reset() -> None:

  """

  Empty stack and set to identity.

  """

  ...

def scale(scale: typing.Sequence[typing.Any]) -> None:

  """

  Scale the current stack matrix.

  """

  ...

def scale_uniform(scale: float) -> None:

  ...

def translate(offset: typing.Sequence[typing.Any]) -> None:

  """

  Scale the current stack matrix.

  """

  ...



"""


Dt Layers Select Src Items
^^^^^^^^^^^^^^^^^^^^^^^^^^

:ACTIVE:          
  Active Layer.

  Only transfer active data layer.

:ALL:             
  All Layers.

  Transfer all data layers.

:BONE_SELECT:     
  Selected Pose Bones.

  Transfer all vertex groups used by selected pose bones.

:BONE_DEFORM:     
  Deform Pose Bones.

  Transfer all vertex groups used by deform bones.

.. _rna-enum-dt-layers-select-src-items:

"""

import typing



"""


Application Timers (bpy.app.timers)
***********************************


Run a Function in x Seconds
===========================

.. code::

  import bpy


  def in_5_seconds():
      print("Hello World")


  bpy.app.timers.register(in_5_seconds, first_interval=5)


Run a Function every x Seconds
==============================

.. code::

  import bpy


  def every_2_seconds():
      print("Hello World")
      return 2.0


  bpy.app.timers.register(every_2_seconds)


Run a Function n times every x seconds
======================================

.. code::

  import bpy

  counter = 0


  def run_10_times():
      global counter
      counter += 1
      print(counter)
      if counter == 10:
          return None
      return 0.1


  bpy.app.timers.register(run_10_times)


Assign parameters to functions
==============================

.. code::

  import bpy
  import functools


  def print_message(message):
      print("Message:", message)


  bpy.app.timers.register(functools.partial(print_message, "Hello"), first_interval=2.0)
  bpy.app.timers.register(functools.partial(print_message, "World"), first_interval=3.0)


Use a Timer to react to events in another thread
================================================

You should never modify Blender data at arbitrary points in time in separate threads.
However you can use a queue to collect all the actions that should be executed when Blender is in the right state again.
Pythons *queue.Queue* can be used here, because it implements the required locking semantics.

.. code::

  import bpy
  import queue

  execution_queue = queue.Queue()


  # This function can safely be called in another thread.
  # The function will be executed when the timer runs the next time.
  def run_in_main_thread(function):
      execution_queue.put(function)


  def execute_queued_functions():
      while not execution_queue.empty():
          function = execution_queue.get()
          function()
      return 1.0


  bpy.app.timers.register(execute_queued_functions)

:func:`is_registered`

:func:`register`

:func:`unregister`

"""

import typing

def is_registered(function: int) -> bool:

  """

  Check if this function is registered as a timer.

  """

  ...

def register(function: typing.Any, first_interval: float = 0, persistent: bool = False) -> None:

  """

  Add a new function that will be called after the specified amount of seconds.
The function gets no arguments and is expected to return either None or a float.
If ``None`` is returned, the timer will be unregistered.
A returned number specifies the delay until the function is called again.
``functools.partial`` can be used to assign some parameters.

  """

  ...

def unregister(function: typing.Callable) -> None:

  """

  Unregister timer.

  """

  ...
